"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QLCDNumber(QFrame):
    """
    https://doc.qt.io/qt-6/qlcdnumber.html

    **Detailed Description**

    ![](images/windows-lcdnumber.png)

    It can display a number in just about any size. It can display decimal,
    hexadecimal, octal or binary numbers. It is easy to connect to data sources
    using the **display** () slot, which is overloaded to take any of five
    argument types.

    There are also slots to change the base with **setMode** () and the decimal
    point with **setSmallDecimalPoint** ().

    QLCDNumber emits the **overflow** () signal when it is asked to display
    something beyond its range. The range is set by **setDigitCount** (), but
    **setSmallDecimalPoint** () also influences it. If the display is set to
    hexadecimal, octal or binary, the integer equivalent of the value is
    displayed.

    These digits and other symbols can be shown: 0/O, 1, 2, 3, 4, 5/S, 6, 7, 8,
    9/g, minus, decimal point, A, B, C, D, E, F, h, H, L, o, P, r, u, U, Y,
    colon, degree sign (which is specified as single quote in the string) and
    space. QLCDNumber substitutes spaces for illegal characters.

    It is not possible to retrieve the contents of a QLCDNumber object, although
    you can retrieve the numeric value with **value** (). If you really need the
    text, we recommend that you connect the signals that feed the **display** ()
    slot to another slot as well and store the value there.

    Incidentally, QLCDNumber is the very oldest part of Qt, tracing its roots
    back to a BASIC program on the **Sinclair Spectrum** .

    **See also** **QLabel** , **QFrame** , **Digital Clock Example** , and
    **Tetrix Example** .
    """

    class SegmentStyle(enum.Enum):
        Outline: QLCDNumber = ...
        Filled: QLCDNumber = ...
        Flat: QLCDNumber = ...

    class Mode(enum.Enum):
        Hex: QLCDNumber = ...
        Dec: QLCDNumber = ...
        Oct: QLCDNumber = ...
        Bin: QLCDNumber = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#QLCDNumber

        **QLCDNumber::QLCDNumber(QWidget * parent = nullptr)**

        Constructs an LCD number, sets the number of digits to 5, the base to
        decimal, the decimal point mode to 'small' and the frame style to a
        raised box. The **segmentStyle** () is set to `Outline`.

        The **parent** argument is passed to the **QFrame**  constructor.

        **See also** **setDigitCount** () and **setSmallDecimalPoint** ().
        """
        ...

    @typing.overload
    def __init__(self, numDigits: int, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#QLCDNumber-1

        **QLCDNumber::QLCDNumber(uint numDigits , QWidget * parent = nullptr)**

        Constructs an LCD number, sets the number of digits to **numDigits** ,
        the base to decimal, the decimal point mode to 'small' and the frame
        style to a raised box. The **segmentStyle** () is set to `Filled`.

        The **parent** argument is passed to the **QFrame**  constructor.

        **See also** **setDigitCount** () and **setSmallDecimalPoint** ().
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#paintEvent

        **[override virtual protected] void QLCDNumber::paintEvent(QPaintEvent
        *)**

        Reimplements: **QFrame::paintEvent** (QPaintEvent *).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#event

        **[override virtual protected] bool QLCDNumber::event(QEvent * e )**

        Reimplements: **QFrame::event** (QEvent *e).
        """
        ...

    def setSmallDecimalPoint(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#smallDecimalPoint-prop

        **smallDecimalPoint : bool**

        This property holds the style of the decimal point

        If true the decimal point is drawn between two digit positions.
        Otherwise it occupies a digit position of its own, i.e. is drawn in a
        digit position. The default is false.

        The inter-digit space is made slightly wider when the decimal point is
        drawn between the digits.

        **Access functions:**

        bool **smallDecimalPoint** () const
        void **setSmallDecimalPoint**
        (bool)

        **See also** **mode** .
        """
        ...

    def setBinMode(self) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#setBinMode

        **[slot] void QLCDNumber::setBinMode()**

        Calls **setMode** (Bin). Provided for convenience (e.g. for connecting
        buttons to it).

        **See also** **setMode** (), **setHexMode** (), **setDecMode** (),
        **setOctMode** (), and **mode** ().
        """
        ...

    def setOctMode(self) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#setOctMode

        **[slot] void QLCDNumber::setOctMode()**

        Calls **setMode** (Oct). Provided for convenience (e.g. for connecting
        buttons to it).

        **See also** **setMode** (), **setHexMode** (), **setDecMode** (),
        **setBinMode** (), and **mode** ().
        """
        ...

    def setDecMode(self) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#setDecMode

        **[slot] void QLCDNumber::setDecMode()**

        Calls **setMode** (Dec). Provided for convenience (e.g. for connecting
        buttons to it).

        **See also** **setMode** (), **setHexMode** (), **setOctMode** (),
        **setBinMode** (), and **mode** ().
        """
        ...

    def setHexMode(self) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#setHexMode

        **[slot] void QLCDNumber::setHexMode()**

        Calls **setMode** (Hex). Provided for convenience (e.g. for connecting
        buttons to it).

        **See also** **setMode** (), **setDecMode** (), **setOctMode** (),
        **setBinMode** (), and **mode** ().
        """
        ...

    @typing.overload
    def display(self, str: str) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#display

        **[slot] void QLCDNumber::display(const QString & s )**

        Displays the number represented by the string **s**.

        This version of the function disregards **mode** () and
        **smallDecimalPoint** ().

        These digits and other symbols can be shown: 0/O, 1, 2, 3, 4, 5/S, 6, 7,
        8, 9/g, minus, decimal point, A, B, C, D, E, F, h, H, L, o, P, r, u, U,
        Y, colon, degree sign (which is specified as single quote in the string)
        and space. **QLCDNumber**  substitutes spaces for illegal characters.

        **Note:** Setter function for property **intValue** . Setter function
        for property **value** .
        """
        ...

    @typing.overload
    def display(self, num: float) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#display-1

        **[slot] void QLCDNumber::display(int num )**

        This is an overloaded function.

        Displays the number **num**.

        **Note:** Setter function for property **intValue** . Setter function
        for property **value** .
        """
        ...

    @typing.overload
    def display(self, num: int) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#display-2

        **[slot] void QLCDNumber::display(double num )**

        This is an overloaded function.

        Displays the number **num**.

        **Note:** Setter function for property **intValue** . Setter function
        for property **value** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#sizeHint

        **[override virtual] QSize QLCDNumber::sizeHint() const**

        Reimplements: **QFrame::sizeHint() const** .
        """
        ...

    def intValue(self) -> int:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#intValue-prop

        **intValue : int**

        This property holds the displayed value rounded to the nearest integer

        This property corresponds to the nearest integer to the current value
        displayed by the LCDNumber. This is the value used for hexadecimal,
        octal and binary modes.

        If the displayed value is not a number, the property has a value of 0.

        By default, this property contains a value of 0.

        **Access functions:**

        int **intValue** () const
        void ****display** ** (const QString & **s**
        )
        void ****display** ** (int **num** )
        void ****display** ** (double
        **num** )
        """
        ...

    def value(self) -> float:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#value-prop

        **value : double**

        This property holds the displayed value

        This property corresponds to the current value displayed by the
        LCDNumber.

        If the displayed value is not a number, the property has a value of 0.

        By default, this property contains a value of 0.

        **Access functions:**

        double **value** () const
        void ****display** ** (const QString & **s**
        )
        void ****display** ** (int **num** )
        void ****display** ** (double
        **num** )

        **Member Function Documentation**
        """
        ...

    def setSegmentStyle(self, a0: "QLCDNumber.SegmentStyle") -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#segmentStyle-prop

        **segmentStyle : SegmentStyle**

        This property holds the style of the LCDNumber

        StyleResult
        `Outline`Produces raised segments filled with the
        background color
        `Filled` (this is the default).Produces raised
        segments filled with the foreground color.
        `Flat`Produces flat
        segments filled with the foreground color.

        `Outline` and `Filled` will additionally use **QPalette::light** () and
        **QPalette::dark** () for shadow effects.

        **Access functions:**

        QLCDNumber::SegmentStyle **segmentStyle** () const
        void
        **setSegmentStyle** (QLCDNumber::SegmentStyle)
        """
        ...

    def segmentStyle(self) -> "QLCDNumber.SegmentStyle":
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#segmentStyle-prop

        **segmentStyle : SegmentStyle**

        This property holds the style of the LCDNumber

        StyleResult
        `Outline`Produces raised segments filled with the
        background color
        `Filled` (this is the default).Produces raised
        segments filled with the foreground color.
        `Flat`Produces flat
        segments filled with the foreground color.

        `Outline` and `Filled` will additionally use **QPalette::light** () and
        **QPalette::dark** () for shadow effects.

        **Access functions:**

        QLCDNumber::SegmentStyle **segmentStyle** () const
        void
        **setSegmentStyle** (QLCDNumber::SegmentStyle)
        """
        ...

    def setMode(self, a0: "QLCDNumber.Mode") -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#mode-prop

        **mode : Mode**

        This property holds the current display mode (number base)

        Corresponds to the current display mode, which is one of `Bin`, `Oct`,
        `Dec` (the default) and `Hex`. `Dec` mode can display floating point
        values, the other modes display the integer equivalent.

        **Access functions:**

        QLCDNumber::Mode **mode** () const
        void **setMode** (QLCDNumber::Mode)

        **See also** **smallDecimalPoint** (), **setHexMode** (), **setDecMode**
        (), **setOctMode** (), and **setBinMode** ().
        """
        ...

    def mode(self) -> "QLCDNumber.Mode":
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#mode-prop

        **mode : Mode**

        This property holds the current display mode (number base)

        Corresponds to the current display mode, which is one of `Bin`, `Oct`,
        `Dec` (the default) and `Hex`. `Dec` mode can display floating point
        values, the other modes display the integer equivalent.

        **Access functions:**

        QLCDNumber::Mode **mode** () const
        void **setMode** (QLCDNumber::Mode)

        **See also** **smallDecimalPoint** (), **setHexMode** (), **setDecMode**
        (), **setOctMode** (), and **setBinMode** ().
        """
        ...

    @typing.overload
    def checkOverflow(self, num: float) -> bool:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#checkOverflow

        **bool QLCDNumber::checkOverflow(double num ) const**

        Returns `true` if **num** is too big to be displayed in its entirety;
        otherwise returns `false`.

        **See also** **display** (), **digitCount** (), and
        **smallDecimalPoint** ().
        """
        ...

    @typing.overload
    def checkOverflow(self, num: int) -> bool:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#checkOverflow-1

        **bool QLCDNumber::checkOverflow(int num ) const**

        This is an overloaded function.

        Returns `true` if **num** is too big to be displayed in its entirety;
        otherwise returns `false`.

        **See also** **display** (), **digitCount** (), and
        **smallDecimalPoint** ().
        """
        ...

    def setNumDigits(self, nDigits: int) -> None:
        ...

    def setDigitCount(self, nDigits: int) -> None:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#setDigitCount

        **void QLCDNumber::setDigitCount(int numDigits )**

        Sets the current number of digits to **numDigits**. Must be in the range
        0..99.

        **Note:** Setter function for property **digitCount** .

        **See also** **digitCount** ().
        """
        ...

    def digitCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#digitCount

        **int QLCDNumber::digitCount() const**

        Returns the current number of digits.

        **Note:** Getter function for property digitCount.

        **See also** **setDigitCount** ().
        """
        ...

    def smallDecimalPoint(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#smallDecimalPoint-prop

        **smallDecimalPoint : bool**

        This property holds the style of the decimal point

        If true the decimal point is drawn between two digit positions.
        Otherwise it occupies a digit position of its own, i.e. is drawn in a
        digit position. The default is false.

        The inter-digit space is made slightly wider when the decimal point is
        drawn between the digits.

        **Access functions:**

        bool **smallDecimalPoint** () const
        void **setSmallDecimalPoint**
        (bool)

        **See also** **mode** .
        """
        ...

    @property
    def overflow(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlcdnumber.html#overflow

        **[signal] void QLCDNumber::overflow()**

        This signal is emitted whenever the **QLCDNumber**  is asked to display
        a too-large number or a too-long string.

        It is never emitted by **setDigitCount** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QVideoFrame(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qvideoframe.html

    **Detailed Description**

    A QVideoFrame encapsulates the pixel data of a video frame, and information
    about the frame.

    Video frames can come from several places - decoded **media** , a **camera**
    , or generated programmatically. The way pixels are described in these
    frames can vary greatly, and some pixel formats offer greater compression
    opportunities at the expense of ease of use.

    The pixel contents of a video frame can be mapped to memory using the
    **map** () function. After a successful call to **map** (), the video data
    can be accessed through various functions. Some of the YUV pixel formats
    provide the data in several planes. The **planeCount** () method will return
    the amount of planes that being used.

    While mapped, the video data of each plane can accessed using the **bits**
    () function, which returns a pointer to a buffer. The size of this buffer is
    given by the **mappedBytes** () function, and the size of each line is given
    by **bytesPerLine** (). The return value of the handle() function may also
    be used to access frame data using the internal buffer's native APIs (for
    example - an OpenGL texture handle).

    A video frame can also have timestamp information associated with it. These
    timestamps can be used to determine when to start and stop displaying the
    frame.

    QVideoFrame objects can consume a significant amount of memory or system
    resources and should not be held for longer than required by the
    application.

    **Note:** Since video frames can be expensive to copy, QVideoFrame is
    explicitly shared, so any change made to a video frame will also apply to
    any copies.
    """

    class MapMode(enum.Enum):
        NotMapped: QVideoFrame = ...
        ReadOnly: QVideoFrame = ...
        WriteOnly: QVideoFrame = ...
        ReadWrite: QVideoFrame = ...

    class HandleType(enum.Enum):
        NoHandle: QVideoFrame = ...
        RhiTextureHandle: QVideoFrame = ...

    class PaintOptions(PyQt6.sip.simplewrapper):
        class PaintFlag(enum.Flag):
            DontDrawSubtitles: QVideoFrame = ...

        aspectRatioMode: QtCore = ...
        backgroundColor: typing = ...
        paintFlags = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QVideoFrame.PaintOptions") -> None:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#QVideoFrame

        **QVideoFrame::QVideoFrame()**

        Constructs a null video frame.
        """
        ...

    @typing.overload
    def __init__(self, format: "QVideoFrameFormat") -> None:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#QVideoFrame-1

        **QVideoFrame::QVideoFrame(const QVideoFrameFormat & format )**

        Constructs a video frame of the given pixel **format**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QVideoFrame") -> None:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#QVideoFrame-2

        **QVideoFrame::QVideoFrame(const QVideoFrame & other )**

        Constructs a shallow copy of **other**. Since QVideoFrame is explicitly
        shared, these two instances will reflect the same frame.
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        rect: QtCore.QRectF,
        options: "QVideoFrame.PaintOptions",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#paint

        **void QVideoFrame::paint(QPainter * painter , const QRectF & rect ,
        const QVideoFrame::PaintOptions & options )**

        Uses a **QPainter** , **painter** , to render this **QVideoFrame**  to
        **rect**. The PaintOptions **options** can be used to specify a
        background color and how **rect** should be filled with the video.

        **Note:** that rendering will usually happen without hardware
        acceleration when using this method.
        """
        ...

    def setSubtitleText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#setSubtitleText

        **void QVideoFrame::setSubtitleText(const QString & text )**

        Sets the subtitle text that should be rendered together with this video
        frame to **text**.

        **See also** **subtitleText** ().
        """
        ...

    def subtitleText(self) -> str:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#subtitleText

        **QString QVideoFrame::subtitleText() const**

        Returns the subtitle text that should be rendered together with this
        video frame.

        **See also** **setSubtitleText** ().
        """
        ...

    def toImage(self) -> QtGui.QImage:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#toImage

        **QImage QVideoFrame::toImage() const**

        Based on the pixel format converts current video frame to image.
        """
        ...

    def surfaceFormat(self) -> "QVideoFrameFormat":
        """
        https://doc.qt.io/qt-6/qvideoframe.html#surfaceFormat

        **QVideoFrameFormat QVideoFrame::surfaceFormat() const**

        Returns the surface format of this video frame.
        """
        ...

    def planeCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#planeCount

        **int QVideoFrame::planeCount() const**

        Returns the number of planes in the video frame.

        **See also** **map** ().
        """
        ...

    def setEndTime(self, time: int) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#setEndTime

        **void QVideoFrame::setEndTime(qint64 time )**

        Sets the presentation **time** (in microseconds) when a frame should
        stop being displayed.

        An invalid time is represented as -1.

        **See also** **endTime** ().
        """
        ...

    def endTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#endTime

        **qint64 QVideoFrame::endTime() const**

        Returns the presentation time (in microseconds) when a frame should stop
        being displayed.

        An invalid time is represented as -1.

        **See also** **setEndTime** ().
        """
        ...

    def setStartTime(self, time: int) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#setStartTime

        **void QVideoFrame::setStartTime(qint64 time )**

        Sets the presentation **time** (in microseconds) when the frame should
        initially be displayed.

        An invalid time is represented as -1.

        **See also** **startTime** ().
        """
        ...

    def startTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#startTime

        **qint64 QVideoFrame::startTime() const**

        Returns the presentation time (in microseconds) when the frame should be
        displayed.

        An invalid time is represented as -1.

        **See also** **setStartTime** ().
        """
        ...

    def mappedBytes(self, plane: int) -> int:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#mappedBytes

        **int QVideoFrame::mappedBytes(int plane ) const**

        Returns the number of bytes occupied by plane **plane** of the mapped
        frame data.

        This value is only valid while the frame data is **mapped** .

        **See also** **map** ().
        """
        ...

    def bits(self, plane: int) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#bits

        **uchar *QVideoFrame::bits(int plane )**

        Returns a pointer to the start of the frame data buffer for a **plane**.

        This value is only valid while the frame data is **mapped** .

        Changes made to data accessed via this pointer (when mapped with write
        access) are only guaranteed to have been persisted when **unmap** () is
        called and when the buffer has been mapped for writing.

        **See also** **map** (), **mappedBytes** (), **bytesPerLine** (), and
        **planeCount** ().
        """
        ...

    def bytesPerLine(self, plane: int) -> int:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#bytesPerLine

        **int QVideoFrame::bytesPerLine(int plane ) const**

        Returns the number of bytes in a scan line of a **plane**.

        This value is only valid while the frame data is **mapped** .

        **See also** **bits** (), **map** (), **mappedBytes** (), and
        **planeCount** ().
        """
        ...

    def unmap(self) -> None:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#unmap

        **void QVideoFrame::unmap()**

        Releases the memory mapped by the **map** () function.

        If the **MapMode**  included the **QVideoFrame::WriteOnly**  flag this
        will persist the current content of the mapped memory to the video
        frame.

        unmap() should not be called if **map** () function failed.

        **See also** **map** ().
        """
        ...

    def map(self, mode: "QVideoFrame.MapMode") -> bool:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#map

        **bool QVideoFrame::map(QVideoFrame::MapMode mode )**

        Maps the contents of a video frame to system (CPU addressable) memory.

        In some cases the video frame data might be stored in video memory or
        otherwise inaccessible memory, so it is necessary to map a frame before
        accessing the pixel data. This may involve copying the contents around,
        so avoid mapping and unmapping unless required.

        The map **mode** indicates whether the contents of the mapped memory
        should be read from and/or written to the frame. If the map mode
        includes the `QVideoFrame::ReadOnly` flag the mapped memory will be
        populated with the content of the video frame when initially mapped. If
        the map mode includes the `QVideoFrame::WriteOnly` flag the content of
        the possibly modified mapped memory will be written back to the frame
        when unmapped.

        While mapped the contents of a video frame can be accessed directly
        through the pointer returned by the **bits** () function.

        When access to the data is no longer needed, be sure to call the
        **unmap** () function to release the mapped memory and possibly update
        the video frame contents.

        If the video frame has been mapped in read only mode, it is permissible
        to map it multiple times in read only mode (and unmap it a corresponding
        number of times). In all other cases it is necessary to unmap the frame
        first before mapping a second time.

        **Note:** Writing to memory that is mapped as read-only is undefined,
        and may result in changes to shared data or crashes.

        Returns true if the frame was mapped to memory in the given **mode** and
        false otherwise.

        **See also** **unmap** (), **mapMode** (), and **bits** ().
        """
        ...

    def mapMode(self) -> "QVideoFrame.MapMode":
        """
        https://doc.qt.io/qt-6/qvideoframe.html#mapMode

        **QVideoFrame::MapMode QVideoFrame::mapMode() const**

        Returns the mode a video frame was mapped to system memory in.

        **See also** **map** () and **QVideoFrame::MapMode** .
        """
        ...

    def isWritable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#isWritable

        **bool QVideoFrame::isWritable() const**

        Identifies if the mapped contents of a video frame will be persisted
        when the frame is unmapped.

        This is a convenience function which checks if the **MapMode**  contains
        the **QVideoFrame::WriteOnly**  flag.

        Returns true if the video frame will be updated when unmapped, and false
        otherwise.

        **Note:** The result of altering the data of a frame that is mapped in
        read-only mode is undefined. Depending on the buffer implementation the
        changes may be persisted, or worse alter a shared buffer.

        **See also** **mapMode** () and **QVideoFrame::MapMode** .
        """
        ...

    def isReadable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#isReadable

        **bool QVideoFrame::isReadable() const**

        Identifies if the mapped contents of a video frame were read from the
        frame when it was mapped.

        This is a convenience function which checks if the **MapMode**  contains
        the **QVideoFrame::WriteOnly**  flag.

        Returns true if the contents of the mapped memory were read from the
        video frame, and false otherwise.

        **See also** **mapMode** () and **QVideoFrame::MapMode** .
        """
        ...

    def isMapped(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#isMapped

        **bool QVideoFrame::isMapped() const**

        Identifies if a video frame's contents are currently mapped to system
        memory.

        This is a convenience function which checks that the **MapMode**  of the
        frame is not equal to **QVideoFrame::NotMapped** .

        Returns true if the contents of the video frame are mapped to system
        memory, and false otherwise.

        **See also** **mapMode** () and **QVideoFrame::MapMode** .
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#height

        **int QVideoFrame::height() const**

        Returns the height of a video frame.
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#width

        **int QVideoFrame::width() const**

        Returns the width of a video frame.
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#size

        **QSize QVideoFrame::size() const**

        Returns the dimensions of a video frame.
        """
        ...

    def handleType(self) -> "QVideoFrame.HandleType":
        """
        https://doc.qt.io/qt-6/qvideoframe.html#handleType

        **QVideoFrame::HandleType QVideoFrame::handleType() const**

        Returns the type of a video frame's handle.

        The handle type could either be **NoHandle** , meaning that the frame is
        memory based, or a RHI texture.
        """
        ...

    def pixelFormat(self) -> "QVideoFrameFormat.PixelFormat":
        """
        https://doc.qt.io/qt-6/qvideoframe.html#pixelFormat

        **QVideoFrameFormat::PixelFormat QVideoFrame::pixelFormat() const**

        Returns the pixel format of this video frame.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvideoframe.html#isValid

        **bool QVideoFrame::isValid() const**

        Identifies whether a video frame is valid.

        An invalid frame has no video buffer associated with it.

        Returns true if the frame is valid, and false if it is not.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QSslEllipticCurve(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsslellipticcurve.html

    **Detailed Description**

    The class QSslEllipticCurve represents an elliptic curve for use by
    elliptic-curve cipher algorithms.

    Elliptic curves can be constructed from a "short name" (SN)
    (**fromShortName** ()), and by a call to
    **QSslConfiguration::supportedEllipticCurves** ().

    QSslEllipticCurve instances can be compared for equality and can be used as
    keys in **QHash**  and **QSet** . They cannot be used as key in a **QMap** .

    **Note:** This class is currently only supported in OpenSSL.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsslellipticcurve.html#QSslEllipticCurve

        **QSslEllipticCurve::QSslEllipticCurve()**

        Constructs an invalid elliptic curve.

        **See also** **isValid** () and
        **QSslConfiguration::supportedEllipticCurves** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QSslEllipticCurve") -> None:
        """
        https://doc.qt.io/qt-6/qsslellipticcurve.html#QSslEllipticCurve

        **QSslEllipticCurve::QSslEllipticCurve()**

        Constructs an invalid elliptic curve.

        **See also** **isValid** () and
        **QSslConfiguration::supportedEllipticCurves** ().
        """
        ...

    def __hash__(self) -> int:
        ...

    def isTlsNamedCurve(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslellipticcurve.html#isTlsNamedCurve

        **bool QSslEllipticCurve::isTlsNamedCurve() const**

        Returns true if this elliptic curve is one of the named curves that can
        be used in the key exchange when using an elliptic curve cipher with
        TLS; false otherwise.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslellipticcurve.html#isValid

        **bool QSslEllipticCurve::isValid() const**

        Returns true if this elliptic curve is a valid curve, false otherwise.
        """
        ...

    def longName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslellipticcurve.html#longName

        **QString QSslEllipticCurve::longName() const**

        Returns the conventional long name for this curve. If this curve is
        invalid, returns an empty string.

        **See also** **shortName** ().
        """
        ...

    def shortName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslellipticcurve.html#shortName

        **QString QSslEllipticCurve::shortName() const**

        Returns the conventional short name for this curve. If this curve is
        invalid, returns an empty string.

        **See also** **longName** ().
        """
        ...

    @staticmethod
    def fromLongName(name: str) -> "QSslEllipticCurve":
        """
        https://doc.qt.io/qt-6/qsslellipticcurve.html#fromLongName

        **[static] QSslEllipticCurve QSslEllipticCurve::fromLongName(const
        QString & name )**

        Returns an **QSslEllipticCurve**  instance representing the named curve
        **name**. The **name** is a long name for the curve, whose exact
        spelling depends on the SSL implementation.

        If the given **name** is not supported, returns an invalid
        **QSslEllipticCurve**  instance.

        **Note:** The OpenSSL implementation of this function treats the name
        case-sensitively.

        **See also** **longName** ().
        """
        ...

    @staticmethod
    def fromShortName(name: str) -> "QSslEllipticCurve":
        """
        https://doc.qt.io/qt-6/qsslellipticcurve.html#fromShortName

        **[static] QSslEllipticCurve QSslEllipticCurve::fromShortName(const
        QString & name )**

        Returns an **QSslEllipticCurve**  instance representing the named curve
        **name**. The **name** is the conventional short name for the curve, as
        represented by RFC 4492 (for instance `secp521r1`), or as NIST short
        names (for instance `P-256`). The actual set of recognized names depends
        on the SSL implementation.

        If the given **name** is not supported, returns an invalid
        **QSslEllipticCurve**  instance.

        **Note:** The OpenSSL implementation of this function treats the name
        case-sensitively.

        **See also** **shortName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6.QtCore import *
import enum


class QCborKnownTags(enum.Enum):
    DateTimeString: QCborKnownTags = ...
    UnixTime_t: QCborKnownTags = ...
    PositiveBignum: QCborKnownTags = ...
    NegativeBignum: QCborKnownTags = ...
    Decimal: QCborKnownTags = ...
    Bigfloat: QCborKnownTags = ...
    COSE_Encrypt0: QCborKnownTags = ...
    COSE_Mac0: QCborKnownTags = ...
    COSE_Sign1: QCborKnownTags = ...
    ExpectedBase64url: QCborKnownTags = ...
    ExpectedBase64: QCborKnownTags = ...
    ExpectedBase16: QCborKnownTags = ...
    EncodedCbor: QCborKnownTags = ...
    Url: QCborKnownTags = ...
    Base64url: QCborKnownTags = ...
    Base64: QCborKnownTags = ...
    RegularExpression: QCborKnownTags = ...
    MimeMessage: QCborKnownTags = ...
    Uuid: QCborKnownTags = ...
    COSE_Encrypt: QCborKnownTags = ...
    COSE_Mac: QCborKnownTags = ...
    COSE_Sign: QCborKnownTags = ...
    Signature: QCborKnownTags = ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6.QtCore import *


class QLoggingCategory(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qloggingcategory.html

    **Detailed Description**

    QLoggingCategory represents a certain logging category - identified by a
    string - at runtime. A category can be configured to enable or disable
    logging of messages per message type.

    To check whether a message type is enabled or not, use one of these methods:
    **isDebugEnabled** (), **isInfoEnabled** (), **isWarningEnabled** (), and
    **isCriticalEnabled** ().

    All objects are meant to be configured by a common registry, as described in
    **Configuring Categories** . Different objects can also represent the same
    category. Therefore, it's **not** recommended to export objects across
    module boundaries, to manipulate the objects directly, or to inherit from
    QLoggingCategory.

    **Creating Category Objects**

    The **Q_DECLARE_LOGGING_CATEGORY** () and **Q_LOGGING_CATEGORY** () macros
    conveniently declare and create QLoggingCategory objects:

    // in a header
        Q_DECLARE_LOGGING_CATEGORY(driverUsb)

        // in one
    source file
        Q_LOGGING_CATEGORY(driverUsb, "driver.usb")

    Category names are free text; to configure categories using **Logging
    Rules** , their names should follow this convention:

    * Use letters and numbers only.
      * Use dots to further structure categories
    into common areas.
      * Avoid the category names: `debug`, `info`, `warning`,
    and `critical`.
      * Category names with the `qt` prefix are solely reserved
    for Qt modules.

    QLoggingCategory objects that are implicitly defined by
    **Q_LOGGING_CATEGORY** () are created on first use, in a thread-safe manner.

    **Checking Category Configuration**

    QLoggingCategory provides **isDebugEnabled** (), **isInfoEnabled** (),
    **isWarningEnabled** (), **isCriticalEnabled** (), as well as **isEnabled**
    () to check whether messages for the given message type should be logged.

    The **qCDebug** (), **qCWarning** (), and **qCCritical** () macros prevent
    arguments from being evaluated if the respective message types are not
    enabled for the category, so explicit checking is not needed:

    // usbEntries() will only be called if driverUsb category is enabled
    qCDebug(driverUsb) << "devices: " << usbEntries();

    **Default Category Configuration**

    Both the QLoggingCategory constructor and the **Q_LOGGING_CATEGORY** ()
    macro accept an optional **QtMsgType**  argument, which disables all message
    types with a lower severity. That is, a category declared with

    Q_LOGGING_CATEGORY(driverUsbEvents, "driver.usb.events", **QtWarningMsg** )

    logs messages of type `QtWarningMsg`, `QtCriticalMsg`, `QtFatalMsg`, but
    ignores messages of type `QtDebugMsg` and `QtInfoMsg`.

    If no argument is passed, all messages are logged. Only Qt internal
    categories which start with `qt` are handled differently: For these, only
    messages of type `QtInfoMsg`, `QtWarningMsg`, and `QtCriticalMsg` are logged
    by default.

    **Note:** Logging categories are not affected by your C++ build
    configuration. That is, whether messages are printed does not change
    depending on whether the code is compiled with debug symbols ('Debug
    Build'), optimizations ('Release Build'), or some other combination.

    **Configuring Categories**

    You can override the default configuration for categories either by setting
    logging rules, or by installing a custom filter.

    **Logging Rules**

    Logging rules let you enable or disable logging for categories in a flexible
    way. Rules are specified in text, where every line must have the format:

    <category>[.<type>] = true|false

    `<category>` is the name of the category, potentially with `*` as a wildcard
    symbol for the first or last character; or at both positions. The optional
    `<type>` must be `debug`, `info`, `warning`, or `critical`. Lines that don't
    fit this scheme are ignored.

    Rules are evaluated in text order, from first to last. That is, if two rules
    apply to a category/type, the rule that comes later is applied.

    Rules can be set via **setFilterRules** ():

    QLoggingCategory::setFilterRules("*.debug=false\\n"
    "driver.usb.debug=true");

    Logging rules are automatically loaded from the `[Rules]` section in a
    logging configuration file. These configuration files are looked up in the
    QtProject configuration directory, or explicitly set in a `QT_LOGGING_CONF`
    environment variable:

    [Rules]
            *.debug=false
            driver.usb.debug=true

    Logging rules can also be specified in a `QT_LOGGING_RULES` environment
    variable; multiple rules can also be separated by semicolons:

    QT_LOGGING_RULES="*.debug=false;driver.usb.debug=true"

    Rules set by **setFilterRules** () take precedence over rules specified in
    the QtProject configuration directory. In turn, these rules can be
    overwritten by those from the configuration file specified by
    `QT_LOGGING_CONF`, and those set by `QT_LOGGING_RULES`.

    The order of evaluation is as follows:

    1. [**QLibraryInfo::DataPath** ]/qtlogging.ini
      2. QtProject/qtlogging.ini
    3. **setFilterRules** ()
      4. `QT_LOGGING_CONF`
      5. `QT_LOGGING_RULES`

    The `QtProject/qtlogging.ini` file is looked up in all directories returned
    by **QStandardPaths::GenericConfigLocation** .

    Set the `QT_LOGGING_DEBUG` environment variable to find out where your
    logging rules are loaded from.

    **Installing a Custom Filter**

    As a lower-level alternative to the text rules, you can also implement a
    custom filter via **installFilter** (). All filter rules are ignored in this
    case.

    **Printing the Category**

    Use the `%{category}` placeholder to print the category in the default
    message handler:

    **qSetMessagePattern** ("%{category} %{message}");
    """

    def __init__(self, category: str, severityLevel: QtMsgType = ...) -> None:
        """
        https://doc.qt.io/qt-6/qloggingcategory.html#QLoggingCategory-1

        **[since 5.4] QLoggingCategory::QLoggingCategory(const char * category ,
        QtMsgType enableForLevel = QtDebugMsg)**

        Constructs a QLoggingCategory object with the provided **category**
        name, and enables all messages with types at least as verbose as
        **enableForLevel** , which defaults to **QtDebugMsg**  (which enables
        all categories).

        If **category** is `nullptr`, the category name `"default"` is used.

        **Note:** **category** must be kept valid during the lifetime of this
        object. Using a string literal for it is the usual way to achieve this.

        This function was introduced in Qt 5.4.
        """
        ...

    @staticmethod
    def setFilterRules(rules: str) -> None:
        """
        https://doc.qt.io/qt-6/qloggingcategory.html#setFilterRules

        **[static] void QLoggingCategory::setFilterRules(const QString & rules
        )**

        Configures which categories and message types should be enabled through
        a set of **rules**.

        Example:

        QLoggingCategory::setFilterRules(**QStringLiteral**
        ("driver.usb.debug=true"));

        **Note:** The rules might be ignored if a custom category filter is
        installed with **installFilter** (), or if the user has defined the
        `QT_LOGGING_CONF` or the `QT_LOGGING_RULES` environment variable.
        """
        ...

    @staticmethod
    def defaultCategory() -> "QLoggingCategory":
        """
        https://doc.qt.io/qt-6/qloggingcategory.html#defaultCategory

        **[static] QLoggingCategory *QLoggingCategory::defaultCategory()**

        Returns a pointer to the global category `"default"` that is used, for
        example, by **qDebug** (), **qInfo** (), **qWarning** (), **qCritical**
        (), or **qFatal** ().

        **Note:** The pointer returned may be null during destruction of static
        objects. Also, don't `delete` this pointer, as ownership of the category
        isn't transferred.
        """
        ...

    def __call__(self) -> "QLoggingCategory":
        ...

    def categoryName(self) -> str:
        """
        https://doc.qt.io/qt-6/qloggingcategory.html#categoryName

        **const char *QLoggingCategory::categoryName() const**

        Returns the name of the category.
        """
        ...

    def isCriticalEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qloggingcategory.html#isCriticalEnabled

        **bool QLoggingCategory::isCriticalEnabled() const**

        Returns `true` if critical messages should be shown for this category;
        `false` otherwise.

        **Note:** The **qCCritical** () macro already does this check before
        executing any code. However, calling this method may be useful to avoid
        the expensive generation of data for debug output only.
        """
        ...

    def isWarningEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qloggingcategory.html#isWarningEnabled

        **bool QLoggingCategory::isWarningEnabled() const**

        Returns `true` if warning messages should be shown for this category;
        `false` otherwise.

        **Note:** The **qCWarning** () macro already does this check before
        executing any code. However, calling this method may be useful to avoid
        the expensive generation of data for debug output only.
        """
        ...

    def isInfoEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qloggingcategory.html#isInfoEnabled

        **[since 5.5] bool QLoggingCategory::isInfoEnabled() const**

        Returns `true` if informational messages should be shown for this
        category; `false` otherwise.

        **Note:** The **qCInfo** () macro already does this check before
        executing any code. However, calling this method may be useful to avoid
        the expensive generation of data for debug output only.

        This function was introduced in Qt 5.5.
        """
        ...

    def isDebugEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qloggingcategory.html#isDebugEnabled

        **bool QLoggingCategory::isDebugEnabled() const**

        Returns `true` if debug messages should be shown for this category;
        `false` otherwise.

        **Note:** The **qCDebug** () macro already does this check before
        running any code. However, calling this method may be useful to avoid
        the expensive generation of data for debug output only.
        """
        ...

    def setEnabled(self, type: QtMsgType, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qloggingcategory.html#setEnabled

        **void QLoggingCategory::setEnabled(QtMsgType type , bool enable )**

        Changes the message type **type** for the category to **enable**.

        This method is meant for use only from inside a filter installed with
        **installFilter** (). For an overview on how to configure categories
        globally, see **Configuring Categories** .

        **Note:**`QtFatalMsg` cannot be changed; it will always remain `true`.

        **See also** **isEnabled** ().
        """
        ...

    def isEnabled(self, type: QtMsgType) -> bool:
        """
        https://doc.qt.io/qt-6/qloggingcategory.html#isEnabled

        **bool QLoggingCategory::isEnabled(QtMsgType msgtype ) const**

        Returns `true` if a message of type **msgtype** for the category should
        be shown; `false` otherwise.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class Qt(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qt.html

    **Detailed Description**
    """

    class HighDpiScaleFactorRoundingPolicy(enum.Enum):
        Round: Qt = ...
        Ceil: Qt = ...
        Floor: Qt = ...
        RoundPreferFloor: Qt = ...
        PassThrough: Qt = ...

    class ChecksumType(enum.Enum):
        ChecksumIso3309: Qt = ...
        ChecksumItuV41: Qt = ...

    class EnterKeyType(enum.Enum):
        EnterKeyDefault: Qt = ...
        EnterKeyReturn: Qt = ...
        EnterKeyDone: Qt = ...
        EnterKeyGo: Qt = ...
        EnterKeySend: Qt = ...
        EnterKeySearch: Qt = ...
        EnterKeyNext: Qt = ...
        EnterKeyPrevious: Qt = ...

    class ItemSelectionOperation(enum.Enum):
        ReplaceSelection: Qt = ...
        AddToSelection: Qt = ...

    class TabFocusBehavior(enum.Enum):
        NoTabFocus: Qt = ...
        TabFocusTextControls: Qt = ...
        TabFocusListControls: Qt = ...
        TabFocusAllControls: Qt = ...

    class MouseEventFlag(enum.Flag):
        MouseEventCreatedDoubleClick: Qt = ...

    class MouseEventSource(enum.Enum):
        MouseEventNotSynthesized: Qt = ...
        MouseEventSynthesizedBySystem: Qt = ...
        MouseEventSynthesizedByQt: Qt = ...
        MouseEventSynthesizedByApplication: Qt = ...

    class ScrollPhase(enum.Enum):
        ScrollBegin: Qt = ...
        ScrollUpdate: Qt = ...
        ScrollEnd: Qt = ...
        NoScrollPhase: Qt = ...
        ScrollMomentum: Qt = ...

    class NativeGestureType(enum.Enum):
        BeginNativeGesture: Qt = ...
        EndNativeGesture: Qt = ...
        PanNativeGesture: Qt = ...
        ZoomNativeGesture: Qt = ...
        SmartZoomNativeGesture: Qt = ...
        RotateNativeGesture: Qt = ...
        SwipeNativeGesture: Qt = ...

    class Edge(enum.Flag):
        TopEdge: Qt = ...
        LeftEdge: Qt = ...
        RightEdge: Qt = ...
        BottomEdge: Qt = ...

    class ApplicationState(enum.Flag):
        ApplicationSuspended: Qt = ...
        ApplicationHidden: Qt = ...
        ApplicationInactive: Qt = ...
        ApplicationActive: Qt = ...

    class HitTestAccuracy(enum.Enum):
        ExactHit: Qt = ...
        FuzzyHit: Qt = ...

    class WhiteSpaceMode(enum.Enum):
        WhiteSpaceNormal: Qt = ...
        WhiteSpacePre: Qt = ...
        WhiteSpaceNoWrap: Qt = ...
        WhiteSpaceModeUndefined: Qt = ...

    class FindChildOption(enum.Flag):
        FindDirectChildrenOnly: Qt = ...
        FindChildrenRecursively: Qt = ...

    class ScreenOrientation(enum.Flag):
        PrimaryOrientation: Qt = ...
        PortraitOrientation: Qt = ...
        LandscapeOrientation: Qt = ...
        InvertedPortraitOrientation: Qt = ...
        InvertedLandscapeOrientation: Qt = ...

    class CursorMoveStyle(enum.Enum):
        LogicalMoveStyle: Qt = ...
        VisualMoveStyle: Qt = ...

    class NavigationMode(enum.Enum):
        NavigationModeNone: Qt = ...
        NavigationModeKeypadTabOrder: Qt = ...
        NavigationModeKeypadDirectional: Qt = ...
        NavigationModeCursorAuto: Qt = ...
        NavigationModeCursorForceVisible: Qt = ...

    class GestureFlag(enum.Flag):
        DontStartGestureOnChildren: Qt = ...
        ReceivePartialGestures: Qt = ...
        IgnoredGesturesPropagateToParent: Qt = ...

    class GestureType(enum.Enum):
        TapGesture: Qt = ...
        TapAndHoldGesture: Qt = ...
        PanGesture: Qt = ...
        PinchGesture: Qt = ...
        SwipeGesture: Qt = ...
        CustomGesture: Qt = ...

    class GestureState(enum.Enum):
        GestureStarted: Qt = ...
        GestureUpdated: Qt = ...
        GestureFinished: Qt = ...
        GestureCanceled: Qt = ...

    class TouchPointState(enum.Flag):
        TouchPointUnknownState: Qt = ...
        TouchPointPressed: Qt = ...
        TouchPointMoved: Qt = ...
        TouchPointStationary: Qt = ...
        TouchPointReleased: Qt = ...

    class CoordinateSystem(enum.Enum):
        DeviceCoordinates: Qt = ...
        LogicalCoordinates: Qt = ...

    class AnchorPoint(enum.Enum):
        AnchorLeft: Qt = ...
        AnchorHorizontalCenter: Qt = ...
        AnchorRight: Qt = ...
        AnchorTop: Qt = ...
        AnchorVerticalCenter: Qt = ...
        AnchorBottom: Qt = ...

    class InputMethodHint(enum.Flag):
        ImhNone: Qt = ...
        ImhHiddenText: Qt = ...
        ImhNoAutoUppercase: Qt = ...
        ImhPreferNumbers: Qt = ...
        ImhPreferUppercase: Qt = ...
        ImhPreferLowercase: Qt = ...
        ImhNoPredictiveText: Qt = ...
        ImhDigitsOnly: Qt = ...
        ImhFormattedNumbersOnly: Qt = ...
        ImhUppercaseOnly: Qt = ...
        ImhLowercaseOnly: Qt = ...
        ImhDialableCharactersOnly: Qt = ...
        ImhEmailCharactersOnly: Qt = ...
        ImhUrlCharactersOnly: Qt = ...
        ImhExclusiveInputMask: Qt = ...
        ImhSensitiveData: Qt = ...
        ImhDate: Qt = ...
        ImhTime: Qt = ...
        ImhPreferLatin: Qt = ...
        ImhLatinOnly: Qt = ...
        ImhMultiLine: Qt = ...
        ImhNoEditMenu: Qt = ...
        ImhNoTextHandles: Qt = ...

    class TileRule(enum.Enum):
        StretchTile: Qt = ...
        RepeatTile: Qt = ...
        RoundTile: Qt = ...

    class WindowFrameSection(enum.Enum):
        NoSection: Qt = ...
        LeftSection: Qt = ...
        TopLeftSection: Qt = ...
        TopSection: Qt = ...
        TopRightSection: Qt = ...
        RightSection: Qt = ...
        BottomRightSection: Qt = ...
        BottomSection: Qt = ...
        BottomLeftSection: Qt = ...
        TitleBarArea: Qt = ...

    class SizeHint(enum.Enum):
        MinimumSize: Qt = ...
        PreferredSize: Qt = ...
        MaximumSize: Qt = ...
        MinimumDescent: Qt = ...

    class SizeMode(enum.Enum):
        AbsoluteSize: Qt = ...
        RelativeSize: Qt = ...

    class EventPriority(enum.Enum):
        HighEventPriority: Qt = ...
        NormalEventPriority: Qt = ...
        LowEventPriority: Qt = ...

    class Axis(enum.Enum):
        XAxis: Qt = ...
        YAxis: Qt = ...
        ZAxis: Qt = ...

    class MaskMode(enum.Enum):
        MaskInColor: Qt = ...
        MaskOutColor: Qt = ...

    class TextInteractionFlag(enum.Flag):
        NoTextInteraction: Qt = ...
        TextSelectableByMouse: Qt = ...
        TextSelectableByKeyboard: Qt = ...
        LinksAccessibleByMouse: Qt = ...
        LinksAccessibleByKeyboard: Qt = ...
        TextEditable: Qt = ...
        TextEditorInteraction: Qt = ...
        TextBrowserInteraction: Qt = ...

    class ItemSelectionMode(enum.Enum):
        ContainsItemShape: Qt = ...
        IntersectsItemShape: Qt = ...
        ContainsItemBoundingRect: Qt = ...
        IntersectsItemBoundingRect: Qt = ...

    class ApplicationAttribute(enum.Enum):
        AA_DontShowIconsInMenus: Qt = ...
        AA_NativeWindows: Qt = ...
        AA_DontCreateNativeWidgetSiblings: Qt = ...
        AA_DontUseNativeMenuBar: Qt = ...
        AA_MacDontSwapCtrlAndMeta: Qt = ...
        AA_Use96Dpi: Qt = ...
        AA_SynthesizeTouchForUnhandledMouseEvents: Qt = ...
        AA_SynthesizeMouseForUnhandledTouchEvents: Qt = ...
        AA_ForceRasterWidgets: Qt = ...
        AA_UseDesktopOpenGL: Qt = ...
        AA_UseOpenGLES: Qt = ...
        AA_UseSoftwareOpenGL: Qt = ...
        AA_ShareOpenGLContexts: Qt = ...
        AA_SetPalette: Qt = ...
        AA_PluginApplication: Qt = ...
        AA_UseStyleSheetPropagationInWidgetStyles: Qt = ...
        AA_DontUseNativeDialogs: Qt = ...
        AA_SynthesizeMouseForUnhandledTabletEvents: Qt = ...
        AA_CompressHighFrequencyEvents: Qt = ...
        AA_DontCheckOpenGLContextThreadAffinity: Qt = ...
        AA_DisableShaderDiskCache: Qt = ...
        AA_DontShowShortcutsInContextMenus: Qt = ...
        AA_CompressTabletEvents: Qt = ...
        AA_DisableSessionManager: Qt = ...
        AA_DisableNativeVirtualKeyboard: Qt = ...

    class WindowModality(enum.Enum):
        NonModal: Qt = ...
        WindowModal: Qt = ...
        ApplicationModal: Qt = ...

    class MatchFlag(enum.Flag):
        MatchExactly: Qt = ...
        MatchFixedString: Qt = ...
        MatchContains: Qt = ...
        MatchStartsWith: Qt = ...
        MatchEndsWith: Qt = ...
        MatchWildcard: Qt = ...
        MatchCaseSensitive: Qt = ...
        MatchWrap: Qt = ...
        MatchRecursive: Qt = ...
        MatchRegularExpression: Qt = ...

    class ItemFlag(enum.Flag):
        NoItemFlags: Qt = ...
        ItemIsSelectable: Qt = ...
        ItemIsEditable: Qt = ...
        ItemIsDragEnabled: Qt = ...
        ItemIsDropEnabled: Qt = ...
        ItemIsUserCheckable: Qt = ...
        ItemIsEnabled: Qt = ...
        ItemNeverHasChildren: Qt = ...
        ItemIsUserTristate: Qt = ...
        ItemIsAutoTristate: Qt = ...

    class ItemDataRole(enum.IntEnum):
        DisplayRole: Qt = ...
        DecorationRole: Qt = ...
        EditRole: Qt = ...
        ToolTipRole: Qt = ...
        StatusTipRole: Qt = ...
        WhatsThisRole: Qt = ...
        FontRole: Qt = ...
        TextAlignmentRole: Qt = ...
        BackgroundRole: Qt = ...
        ForegroundRole: Qt = ...
        CheckStateRole: Qt = ...
        AccessibleTextRole: Qt = ...
        AccessibleDescriptionRole: Qt = ...
        SizeHintRole: Qt = ...
        InitialSortOrderRole: Qt = ...
        UserRole: Qt = ...

    class CheckState(enum.Enum):
        Unchecked: Qt = ...
        PartiallyChecked: Qt = ...
        Checked: Qt = ...

    class DropAction(enum.Flag):
        CopyAction: Qt = ...
        MoveAction: Qt = ...
        LinkAction: Qt = ...
        ActionMask: Qt = ...
        TargetMoveAction: Qt = ...
        IgnoreAction: Qt = ...

    class LayoutDirection(enum.Enum):
        LeftToRight: Qt = ...
        RightToLeft: Qt = ...
        LayoutDirectionAuto: Qt = ...

    class ToolButtonStyle(enum.Enum):
        ToolButtonIconOnly: Qt = ...
        ToolButtonTextOnly: Qt = ...
        ToolButtonTextBesideIcon: Qt = ...
        ToolButtonTextUnderIcon: Qt = ...
        ToolButtonFollowStyle: Qt = ...

    class InputMethodQuery(enum.Flag):
        ImFont: Qt = ...
        ImCursorPosition: Qt = ...
        ImSurroundingText: Qt = ...
        ImCurrentSelection: Qt = ...
        ImMaximumTextLength: Qt = ...
        ImAnchorPosition: Qt = ...
        ImEnabled: Qt = ...
        ImCursorRectangle: Qt = ...
        ImHints: Qt = ...
        ImPreferredLanguage: Qt = ...
        ImPlatformData: Qt = ...
        ImQueryInput: Qt = ...
        ImQueryAll: Qt = ...
        ImAbsolutePosition: Qt = ...
        ImTextBeforeCursor: Qt = ...
        ImTextAfterCursor: Qt = ...
        ImEnterKeyType: Qt = ...
        ImAnchorRectangle: Qt = ...
        ImInputItemClipRectangle: Qt = ...
        ImReadOnly: Qt = ...

    class ContextMenuPolicy(enum.Enum):
        NoContextMenu: Qt = ...
        PreventContextMenu: Qt = ...
        DefaultContextMenu: Qt = ...
        ActionsContextMenu: Qt = ...
        CustomContextMenu: Qt = ...

    class FocusReason(enum.Enum):
        MouseFocusReason: Qt = ...
        TabFocusReason: Qt = ...
        BacktabFocusReason: Qt = ...
        ActiveWindowFocusReason: Qt = ...
        PopupFocusReason: Qt = ...
        ShortcutFocusReason: Qt = ...
        MenuBarFocusReason: Qt = ...
        OtherFocusReason: Qt = ...
        NoFocusReason: Qt = ...

    class TransformationMode(enum.Enum):
        FastTransformation: Qt = ...
        SmoothTransformation: Qt = ...

    class ClipOperation(enum.Enum):
        NoClip: Qt = ...
        ReplaceClip: Qt = ...
        IntersectClip: Qt = ...

    class FillRule(enum.Enum):
        OddEvenFill: Qt = ...
        WindingFill: Qt = ...

    class ShortcutContext(enum.Enum):
        WidgetShortcut: Qt = ...
        WindowShortcut: Qt = ...
        ApplicationShortcut: Qt = ...
        WidgetWithChildrenShortcut: Qt = ...

    class ConnectionType(enum.Enum):
        AutoConnection: Qt = ...
        DirectConnection: Qt = ...
        QueuedConnection: Qt = ...
        BlockingQueuedConnection: Qt = ...
        UniqueConnection: Qt = ...
        SingleShotConnection: Qt = ...

    class Corner(enum.Enum):
        TopLeftCorner: Qt = ...
        TopRightCorner: Qt = ...
        BottomLeftCorner: Qt = ...
        BottomRightCorner: Qt = ...

    class CaseSensitivity(enum.Enum):
        CaseInsensitive: Qt = ...
        CaseSensitive: Qt = ...

    class ScrollBarPolicy(enum.Enum):
        ScrollBarAsNeeded: Qt = ...
        ScrollBarAlwaysOff: Qt = ...
        ScrollBarAlwaysOn: Qt = ...

    class DayOfWeek(enum.Enum):
        Monday: Qt = ...
        Tuesday: Qt = ...
        Wednesday: Qt = ...
        Thursday: Qt = ...
        Friday: Qt = ...
        Saturday: Qt = ...
        Sunday: Qt = ...

    class TimeSpec(enum.Enum):
        LocalTime: Qt = ...
        UTC: Qt = ...
        OffsetFromUTC: Qt = ...
        TimeZone: Qt = ...

    class DateFormat(enum.Enum):
        TextDate: Qt = ...
        ISODate: Qt = ...
        ISODateWithMs: Qt = ...
        RFC2822Date: Qt = ...

    class ToolBarArea(enum.Flag):
        LeftToolBarArea: Qt = ...
        RightToolBarArea: Qt = ...
        TopToolBarArea: Qt = ...
        BottomToolBarArea: Qt = ...
        AllToolBarAreas: Qt = ...
        NoToolBarArea: Qt = ...

    class TimerType(enum.Enum):
        PreciseTimer: Qt = ...
        CoarseTimer: Qt = ...
        VeryCoarseTimer: Qt = ...

    class DockWidgetArea(enum.Flag):
        LeftDockWidgetArea: Qt = ...
        RightDockWidgetArea: Qt = ...
        TopDockWidgetArea: Qt = ...
        BottomDockWidgetArea: Qt = ...
        AllDockWidgetAreas: Qt = ...
        NoDockWidgetArea: Qt = ...

    class AspectRatioMode(enum.Enum):
        IgnoreAspectRatio: Qt = ...
        KeepAspectRatio: Qt = ...
        KeepAspectRatioByExpanding: Qt = ...

    class TextFormat(enum.Enum):
        PlainText: Qt = ...
        RichText: Qt = ...
        AutoText: Qt = ...
        MarkdownText: Qt = ...

    class CursorShape(enum.Enum):
        ArrowCursor: Qt = ...
        UpArrowCursor: Qt = ...
        CrossCursor: Qt = ...
        WaitCursor: Qt = ...
        IBeamCursor: Qt = ...
        SizeVerCursor: Qt = ...
        SizeHorCursor: Qt = ...
        SizeBDiagCursor: Qt = ...
        SizeFDiagCursor: Qt = ...
        SizeAllCursor: Qt = ...
        BlankCursor: Qt = ...
        SplitVCursor: Qt = ...
        SplitHCursor: Qt = ...
        PointingHandCursor: Qt = ...
        ForbiddenCursor: Qt = ...
        OpenHandCursor: Qt = ...
        ClosedHandCursor: Qt = ...
        WhatsThisCursor: Qt = ...
        BusyCursor: Qt = ...
        LastCursor: Qt = ...
        BitmapCursor: Qt = ...
        CustomCursor: Qt = ...
        DragCopyCursor: Qt = ...
        DragMoveCursor: Qt = ...
        DragLinkCursor: Qt = ...

    class UIEffect(enum.Enum):
        UI_General: Qt = ...
        UI_AnimateMenu: Qt = ...
        UI_FadeMenu: Qt = ...
        UI_AnimateCombo: Qt = ...
        UI_AnimateTooltip: Qt = ...
        UI_FadeTooltip: Qt = ...
        UI_AnimateToolBox: Qt = ...

    class BrushStyle(enum.Enum):
        NoBrush: Qt = ...
        SolidPattern: Qt = ...
        Dense1Pattern: Qt = ...
        Dense2Pattern: Qt = ...
        Dense3Pattern: Qt = ...
        Dense4Pattern: Qt = ...
        Dense5Pattern: Qt = ...
        Dense6Pattern: Qt = ...
        Dense7Pattern: Qt = ...
        HorPattern: Qt = ...
        VerPattern: Qt = ...
        CrossPattern: Qt = ...
        BDiagPattern: Qt = ...
        FDiagPattern: Qt = ...
        DiagCrossPattern: Qt = ...
        LinearGradientPattern: Qt = ...
        RadialGradientPattern: Qt = ...
        ConicalGradientPattern: Qt = ...
        TexturePattern: Qt = ...

    class PenJoinStyle(enum.Enum):
        MiterJoin: Qt = ...
        BevelJoin: Qt = ...
        RoundJoin: Qt = ...
        MPenJoinStyle: Qt = ...
        SvgMiterJoin: Qt = ...

    class PenCapStyle(enum.Enum):
        FlatCap: Qt = ...
        SquareCap: Qt = ...
        RoundCap: Qt = ...

    class PenStyle(enum.Enum):
        NoPen: Qt = ...
        SolidLine: Qt = ...
        DashLine: Qt = ...
        DotLine: Qt = ...
        DashDotLine: Qt = ...
        DashDotDotLine: Qt = ...
        CustomDashLine: Qt = ...

    class ArrowType(enum.Enum):
        NoArrow: Qt = ...
        UpArrow: Qt = ...
        DownArrow: Qt = ...
        LeftArrow: Qt = ...
        RightArrow: Qt = ...

    class Key(enum.IntEnum):
        Key_Escape: Qt = ...
        Key_Tab: Qt = ...
        Key_Backtab: Qt = ...
        Key_Backspace: Qt = ...
        Key_Return: Qt = ...
        Key_Enter: Qt = ...
        Key_Insert: Qt = ...
        Key_Delete: Qt = ...
        Key_Pause: Qt = ...
        Key_Print: Qt = ...
        Key_SysReq: Qt = ...
        Key_Clear: Qt = ...
        Key_Home: Qt = ...
        Key_End: Qt = ...
        Key_Left: Qt = ...
        Key_Up: Qt = ...
        Key_Right: Qt = ...
        Key_Down: Qt = ...
        Key_PageUp: Qt = ...
        Key_PageDown: Qt = ...
        Key_Shift: Qt = ...
        Key_Control: Qt = ...
        Key_Meta: Qt = ...
        Key_Alt: Qt = ...
        Key_CapsLock: Qt = ...
        Key_NumLock: Qt = ...
        Key_ScrollLock: Qt = ...
        Key_F1: Qt = ...
        Key_F2: Qt = ...
        Key_F3: Qt = ...
        Key_F4: Qt = ...
        Key_F5: Qt = ...
        Key_F6: Qt = ...
        Key_F7: Qt = ...
        Key_F8: Qt = ...
        Key_F9: Qt = ...
        Key_F10: Qt = ...
        Key_F11: Qt = ...
        Key_F12: Qt = ...
        Key_F13: Qt = ...
        Key_F14: Qt = ...
        Key_F15: Qt = ...
        Key_F16: Qt = ...
        Key_F17: Qt = ...
        Key_F18: Qt = ...
        Key_F19: Qt = ...
        Key_F20: Qt = ...
        Key_F21: Qt = ...
        Key_F22: Qt = ...
        Key_F23: Qt = ...
        Key_F24: Qt = ...
        Key_F25: Qt = ...
        Key_F26: Qt = ...
        Key_F27: Qt = ...
        Key_F28: Qt = ...
        Key_F29: Qt = ...
        Key_F30: Qt = ...
        Key_F31: Qt = ...
        Key_F32: Qt = ...
        Key_F33: Qt = ...
        Key_F34: Qt = ...
        Key_F35: Qt = ...
        Key_Super_L: Qt = ...
        Key_Super_R: Qt = ...
        Key_Menu: Qt = ...
        Key_Hyper_L: Qt = ...
        Key_Hyper_R: Qt = ...
        Key_Help: Qt = ...
        Key_Direction_L: Qt = ...
        Key_Direction_R: Qt = ...
        Key_Space: Qt = ...
        Key_Any: Qt = ...
        Key_Exclam: Qt = ...
        Key_QuoteDbl: Qt = ...
        Key_NumberSign: Qt = ...
        Key_Dollar: Qt = ...
        Key_Percent: Qt = ...
        Key_Ampersand: Qt = ...
        Key_Apostrophe: Qt = ...
        Key_ParenLeft: Qt = ...
        Key_ParenRight: Qt = ...
        Key_Asterisk: Qt = ...
        Key_Plus: Qt = ...
        Key_Comma: Qt = ...
        Key_Minus: Qt = ...
        Key_Period: Qt = ...
        Key_Slash: Qt = ...
        Key_0: Qt = ...
        Key_1: Qt = ...
        Key_2: Qt = ...
        Key_3: Qt = ...
        Key_4: Qt = ...
        Key_5: Qt = ...
        Key_6: Qt = ...
        Key_7: Qt = ...
        Key_8: Qt = ...
        Key_9: Qt = ...
        Key_Colon: Qt = ...
        Key_Semicolon: Qt = ...
        Key_Less: Qt = ...
        Key_Equal: Qt = ...
        Key_Greater: Qt = ...
        Key_Question: Qt = ...
        Key_At: Qt = ...
        Key_A: Qt = ...
        Key_B: Qt = ...
        Key_C: Qt = ...
        Key_D: Qt = ...
        Key_E: Qt = ...
        Key_F: Qt = ...
        Key_G: Qt = ...
        Key_H: Qt = ...
        Key_I: Qt = ...
        Key_J: Qt = ...
        Key_K: Qt = ...
        Key_L: Qt = ...
        Key_M: Qt = ...
        Key_N: Qt = ...
        Key_O: Qt = ...
        Key_P: Qt = ...
        Key_Q: Qt = ...
        Key_R: Qt = ...
        Key_S: Qt = ...
        Key_T: Qt = ...
        Key_U: Qt = ...
        Key_V: Qt = ...
        Key_W: Qt = ...
        Key_X: Qt = ...
        Key_Y: Qt = ...
        Key_Z: Qt = ...
        Key_BracketLeft: Qt = ...
        Key_Backslash: Qt = ...
        Key_BracketRight: Qt = ...
        Key_AsciiCircum: Qt = ...
        Key_Underscore: Qt = ...
        Key_QuoteLeft: Qt = ...
        Key_BraceLeft: Qt = ...
        Key_Bar: Qt = ...
        Key_BraceRight: Qt = ...
        Key_AsciiTilde: Qt = ...
        Key_nobreakspace: Qt = ...
        Key_exclamdown: Qt = ...
        Key_cent: Qt = ...
        Key_sterling: Qt = ...
        Key_currency: Qt = ...
        Key_yen: Qt = ...
        Key_brokenbar: Qt = ...
        Key_section: Qt = ...
        Key_diaeresis: Qt = ...
        Key_copyright: Qt = ...
        Key_ordfeminine: Qt = ...
        Key_guillemotleft: Qt = ...
        Key_notsign: Qt = ...
        Key_hyphen: Qt = ...
        Key_registered: Qt = ...
        Key_macron: Qt = ...
        Key_degree: Qt = ...
        Key_plusminus: Qt = ...
        Key_twosuperior: Qt = ...
        Key_threesuperior: Qt = ...
        Key_acute: Qt = ...
        Key_mu: Qt = ...
        Key_paragraph: Qt = ...
        Key_periodcentered: Qt = ...
        Key_cedilla: Qt = ...
        Key_onesuperior: Qt = ...
        Key_masculine: Qt = ...
        Key_guillemotright: Qt = ...
        Key_onequarter: Qt = ...
        Key_onehalf: Qt = ...
        Key_threequarters: Qt = ...
        Key_questiondown: Qt = ...
        Key_Agrave: Qt = ...
        Key_Aacute: Qt = ...
        Key_Acircumflex: Qt = ...
        Key_Atilde: Qt = ...
        Key_Adiaeresis: Qt = ...
        Key_Aring: Qt = ...
        Key_AE: Qt = ...
        Key_Ccedilla: Qt = ...
        Key_Egrave: Qt = ...
        Key_Eacute: Qt = ...
        Key_Ecircumflex: Qt = ...
        Key_Ediaeresis: Qt = ...
        Key_Igrave: Qt = ...
        Key_Iacute: Qt = ...
        Key_Icircumflex: Qt = ...
        Key_Idiaeresis: Qt = ...
        Key_ETH: Qt = ...
        Key_Ntilde: Qt = ...
        Key_Ograve: Qt = ...
        Key_Oacute: Qt = ...
        Key_Ocircumflex: Qt = ...
        Key_Otilde: Qt = ...
        Key_Odiaeresis: Qt = ...
        Key_multiply: Qt = ...
        Key_Ooblique: Qt = ...
        Key_Ugrave: Qt = ...
        Key_Uacute: Qt = ...
        Key_Ucircumflex: Qt = ...
        Key_Udiaeresis: Qt = ...
        Key_Yacute: Qt = ...
        Key_THORN: Qt = ...
        Key_ssharp: Qt = ...
        Key_division: Qt = ...
        Key_ydiaeresis: Qt = ...
        Key_AltGr: Qt = ...
        Key_Multi_key: Qt = ...
        Key_Codeinput: Qt = ...
        Key_SingleCandidate: Qt = ...
        Key_MultipleCandidate: Qt = ...
        Key_PreviousCandidate: Qt = ...
        Key_Mode_switch: Qt = ...
        Key_Kanji: Qt = ...
        Key_Muhenkan: Qt = ...
        Key_Henkan: Qt = ...
        Key_Romaji: Qt = ...
        Key_Hiragana: Qt = ...
        Key_Katakana: Qt = ...
        Key_Hiragana_Katakana: Qt = ...
        Key_Zenkaku: Qt = ...
        Key_Hankaku: Qt = ...
        Key_Zenkaku_Hankaku: Qt = ...
        Key_Touroku: Qt = ...
        Key_Massyo: Qt = ...
        Key_Kana_Lock: Qt = ...
        Key_Kana_Shift: Qt = ...
        Key_Eisu_Shift: Qt = ...
        Key_Eisu_toggle: Qt = ...
        Key_Hangul: Qt = ...
        Key_Hangul_Start: Qt = ...
        Key_Hangul_End: Qt = ...
        Key_Hangul_Hanja: Qt = ...
        Key_Hangul_Jamo: Qt = ...
        Key_Hangul_Romaja: Qt = ...
        Key_Hangul_Jeonja: Qt = ...
        Key_Hangul_Banja: Qt = ...
        Key_Hangul_PreHanja: Qt = ...
        Key_Hangul_PostHanja: Qt = ...
        Key_Hangul_Special: Qt = ...
        Key_Dead_Grave: Qt = ...
        Key_Dead_Acute: Qt = ...
        Key_Dead_Circumflex: Qt = ...
        Key_Dead_Tilde: Qt = ...
        Key_Dead_Macron: Qt = ...
        Key_Dead_Breve: Qt = ...
        Key_Dead_Abovedot: Qt = ...
        Key_Dead_Diaeresis: Qt = ...
        Key_Dead_Abovering: Qt = ...
        Key_Dead_Doubleacute: Qt = ...
        Key_Dead_Caron: Qt = ...
        Key_Dead_Cedilla: Qt = ...
        Key_Dead_Ogonek: Qt = ...
        Key_Dead_Iota: Qt = ...
        Key_Dead_Voiced_Sound: Qt = ...
        Key_Dead_Semivoiced_Sound: Qt = ...
        Key_Dead_Belowdot: Qt = ...
        Key_Dead_Hook: Qt = ...
        Key_Dead_Horn: Qt = ...
        Key_Back: Qt = ...
        Key_Forward: Qt = ...
        Key_Stop: Qt = ...
        Key_Refresh: Qt = ...
        Key_VolumeDown: Qt = ...
        Key_VolumeMute: Qt = ...
        Key_VolumeUp: Qt = ...
        Key_BassBoost: Qt = ...
        Key_BassUp: Qt = ...
        Key_BassDown: Qt = ...
        Key_TrebleUp: Qt = ...
        Key_TrebleDown: Qt = ...
        Key_MediaPlay: Qt = ...
        Key_MediaStop: Qt = ...
        Key_MediaPrevious: Qt = ...
        Key_MediaNext: Qt = ...
        Key_MediaRecord: Qt = ...
        Key_HomePage: Qt = ...
        Key_Favorites: Qt = ...
        Key_Search: Qt = ...
        Key_Standby: Qt = ...
        Key_OpenUrl: Qt = ...
        Key_LaunchMail: Qt = ...
        Key_LaunchMedia: Qt = ...
        Key_Launch0: Qt = ...
        Key_Launch1: Qt = ...
        Key_Launch2: Qt = ...
        Key_Launch3: Qt = ...
        Key_Launch4: Qt = ...
        Key_Launch5: Qt = ...
        Key_Launch6: Qt = ...
        Key_Launch7: Qt = ...
        Key_Launch8: Qt = ...
        Key_Launch9: Qt = ...
        Key_LaunchA: Qt = ...
        Key_LaunchB: Qt = ...
        Key_LaunchC: Qt = ...
        Key_LaunchD: Qt = ...
        Key_LaunchE: Qt = ...
        Key_LaunchF: Qt = ...
        Key_MediaLast: Qt = ...
        Key_Select: Qt = ...
        Key_Yes: Qt = ...
        Key_No: Qt = ...
        Key_Context1: Qt = ...
        Key_Context2: Qt = ...
        Key_Context3: Qt = ...
        Key_Context4: Qt = ...
        Key_Call: Qt = ...
        Key_Hangup: Qt = ...
        Key_Flip: Qt = ...
        Key_unknown: Qt = ...
        Key_Execute: Qt = ...
        Key_Printer: Qt = ...
        Key_Play: Qt = ...
        Key_Sleep: Qt = ...
        Key_Zoom: Qt = ...
        Key_Cancel: Qt = ...
        Key_MonBrightnessUp: Qt = ...
        Key_MonBrightnessDown: Qt = ...
        Key_KeyboardLightOnOff: Qt = ...
        Key_KeyboardBrightnessUp: Qt = ...
        Key_KeyboardBrightnessDown: Qt = ...
        Key_PowerOff: Qt = ...
        Key_WakeUp: Qt = ...
        Key_Eject: Qt = ...
        Key_ScreenSaver: Qt = ...
        Key_WWW: Qt = ...
        Key_Memo: Qt = ...
        Key_LightBulb: Qt = ...
        Key_Shop: Qt = ...
        Key_History: Qt = ...
        Key_AddFavorite: Qt = ...
        Key_HotLinks: Qt = ...
        Key_BrightnessAdjust: Qt = ...
        Key_Finance: Qt = ...
        Key_Community: Qt = ...
        Key_AudioRewind: Qt = ...
        Key_BackForward: Qt = ...
        Key_ApplicationLeft: Qt = ...
        Key_ApplicationRight: Qt = ...
        Key_Book: Qt = ...
        Key_CD: Qt = ...
        Key_Calculator: Qt = ...
        Key_ToDoList: Qt = ...
        Key_ClearGrab: Qt = ...
        Key_Close: Qt = ...
        Key_Copy: Qt = ...
        Key_Cut: Qt = ...
        Key_Display: Qt = ...
        Key_DOS: Qt = ...
        Key_Documents: Qt = ...
        Key_Excel: Qt = ...
        Key_Explorer: Qt = ...
        Key_Game: Qt = ...
        Key_Go: Qt = ...
        Key_iTouch: Qt = ...
        Key_LogOff: Qt = ...
        Key_Market: Qt = ...
        Key_Meeting: Qt = ...
        Key_MenuKB: Qt = ...
        Key_MenuPB: Qt = ...
        Key_MySites: Qt = ...
        Key_News: Qt = ...
        Key_OfficeHome: Qt = ...
        Key_Option: Qt = ...
        Key_Paste: Qt = ...
        Key_Phone: Qt = ...
        Key_Calendar: Qt = ...
        Key_Reply: Qt = ...
        Key_Reload: Qt = ...
        Key_RotateWindows: Qt = ...
        Key_RotationPB: Qt = ...
        Key_RotationKB: Qt = ...
        Key_Save: Qt = ...
        Key_Send: Qt = ...
        Key_Spell: Qt = ...
        Key_SplitScreen: Qt = ...
        Key_Support: Qt = ...
        Key_TaskPane: Qt = ...
        Key_Terminal: Qt = ...
        Key_Tools: Qt = ...
        Key_Travel: Qt = ...
        Key_Video: Qt = ...
        Key_Word: Qt = ...
        Key_Xfer: Qt = ...
        Key_ZoomIn: Qt = ...
        Key_ZoomOut: Qt = ...
        Key_Away: Qt = ...
        Key_Messenger: Qt = ...
        Key_WebCam: Qt = ...
        Key_MailForward: Qt = ...
        Key_Pictures: Qt = ...
        Key_Music: Qt = ...
        Key_Battery: Qt = ...
        Key_Bluetooth: Qt = ...
        Key_WLAN: Qt = ...
        Key_UWB: Qt = ...
        Key_AudioForward: Qt = ...
        Key_AudioRepeat: Qt = ...
        Key_AudioRandomPlay: Qt = ...
        Key_Subtitle: Qt = ...
        Key_AudioCycleTrack: Qt = ...
        Key_Time: Qt = ...
        Key_Hibernate: Qt = ...
        Key_View: Qt = ...
        Key_TopMenu: Qt = ...
        Key_PowerDown: Qt = ...
        Key_Suspend: Qt = ...
        Key_ContrastAdjust: Qt = ...
        Key_MediaPause: Qt = ...
        Key_MediaTogglePlayPause: Qt = ...
        Key_LaunchG: Qt = ...
        Key_LaunchH: Qt = ...
        Key_ToggleCallHangup: Qt = ...
        Key_VoiceDial: Qt = ...
        Key_LastNumberRedial: Qt = ...
        Key_Camera: Qt = ...
        Key_CameraFocus: Qt = ...
        Key_TouchpadToggle: Qt = ...
        Key_TouchpadOn: Qt = ...
        Key_TouchpadOff: Qt = ...
        Key_MicMute: Qt = ...
        Key_Red: Qt = ...
        Key_Green: Qt = ...
        Key_Yellow: Qt = ...
        Key_Blue: Qt = ...
        Key_ChannelUp: Qt = ...
        Key_ChannelDown: Qt = ...
        Key_Guide: Qt = ...
        Key_Info: Qt = ...
        Key_Settings: Qt = ...
        Key_Exit: Qt = ...
        Key_MicVolumeUp: Qt = ...
        Key_MicVolumeDown: Qt = ...
        Key_New: Qt = ...
        Key_Open: Qt = ...
        Key_Find: Qt = ...
        Key_Undo: Qt = ...
        Key_Redo: Qt = ...
        Key_Dead_Stroke: Qt = ...
        Key_Dead_Abovecomma: Qt = ...
        Key_Dead_Abovereversedcomma: Qt = ...
        Key_Dead_Doublegrave: Qt = ...
        Key_Dead_Belowring: Qt = ...
        Key_Dead_Belowmacron: Qt = ...
        Key_Dead_Belowcircumflex: Qt = ...
        Key_Dead_Belowtilde: Qt = ...
        Key_Dead_Belowbreve: Qt = ...
        Key_Dead_Belowdiaeresis: Qt = ...
        Key_Dead_Invertedbreve: Qt = ...
        Key_Dead_Belowcomma: Qt = ...
        Key_Dead_Currency: Qt = ...
        Key_Dead_a: Qt = ...
        Key_Dead_A: Qt = ...
        Key_Dead_e: Qt = ...
        Key_Dead_E: Qt = ...
        Key_Dead_i: Qt = ...
        Key_Dead_I: Qt = ...
        Key_Dead_o: Qt = ...
        Key_Dead_O: Qt = ...
        Key_Dead_u: Qt = ...
        Key_Dead_U: Qt = ...
        Key_Dead_Small_Schwa: Qt = ...
        Key_Dead_Capital_Schwa: Qt = ...
        Key_Dead_Greek: Qt = ...
        Key_Dead_Lowline: Qt = ...
        Key_Dead_Aboveverticalline: Qt = ...
        Key_Dead_Belowverticalline: Qt = ...
        Key_Dead_Longsolidusoverlay: Qt = ...

    class BGMode(enum.Enum):
        TransparentMode: Qt = ...
        OpaqueMode: Qt = ...

    class ImageConversionFlag(enum.Flag):
        AutoColor: Qt = ...
        ColorOnly: Qt = ...
        MonoOnly: Qt = ...
        ThresholdAlphaDither: Qt = ...
        OrderedAlphaDither: Qt = ...
        DiffuseAlphaDither: Qt = ...
        DiffuseDither: Qt = ...
        OrderedDither: Qt = ...
        ThresholdDither: Qt = ...
        AutoDither: Qt = ...
        PreferDither: Qt = ...
        AvoidDither: Qt = ...
        NoOpaqueDetection: Qt = ...
        NoFormatConversion: Qt = ...

    class WidgetAttribute(enum.Enum):
        WA_Disabled: Qt = ...
        WA_UnderMouse: Qt = ...
        WA_MouseTracking: Qt = ...
        WA_OpaquePaintEvent: Qt = ...
        WA_StaticContents: Qt = ...
        WA_LaidOut: Qt = ...
        WA_PaintOnScreen: Qt = ...
        WA_NoSystemBackground: Qt = ...
        WA_UpdatesDisabled: Qt = ...
        WA_Mapped: Qt = ...
        WA_InputMethodEnabled: Qt = ...
        WA_WState_Visible: Qt = ...
        WA_WState_Hidden: Qt = ...
        WA_ForceDisabled: Qt = ...
        WA_KeyCompression: Qt = ...
        WA_PendingMoveEvent: Qt = ...
        WA_PendingResizeEvent: Qt = ...
        WA_SetPalette: Qt = ...
        WA_SetFont: Qt = ...
        WA_SetCursor: Qt = ...
        WA_NoChildEventsFromChildren: Qt = ...
        WA_WindowModified: Qt = ...
        WA_Resized: Qt = ...
        WA_Moved: Qt = ...
        WA_PendingUpdate: Qt = ...
        WA_InvalidSize: Qt = ...
        WA_CustomWhatsThis: Qt = ...
        WA_LayoutOnEntireRect: Qt = ...
        WA_OutsideWSRange: Qt = ...
        WA_GrabbedShortcut: Qt = ...
        WA_TransparentForMouseEvents: Qt = ...
        WA_PaintUnclipped: Qt = ...
        WA_SetWindowIcon: Qt = ...
        WA_NoMouseReplay: Qt = ...
        WA_DeleteOnClose: Qt = ...
        WA_RightToLeft: Qt = ...
        WA_SetLayoutDirection: Qt = ...
        WA_NoChildEventsForParent: Qt = ...
        WA_ForceUpdatesDisabled: Qt = ...
        WA_WState_Created: Qt = ...
        WA_WState_CompressKeys: Qt = ...
        WA_WState_InPaintEvent: Qt = ...
        WA_WState_Reparented: Qt = ...
        WA_WState_ConfigPending: Qt = ...
        WA_WState_Polished: Qt = ...
        WA_WState_OwnSizePolicy: Qt = ...
        WA_WState_ExplicitShowHide: Qt = ...
        WA_MouseNoMask: Qt = ...
        WA_NoMousePropagation: Qt = ...
        WA_Hover: Qt = ...
        WA_InputMethodTransparent: Qt = ...
        WA_QuitOnClose: Qt = ...
        WA_KeyboardFocusChange: Qt = ...
        WA_AcceptDrops: Qt = ...
        WA_WindowPropagation: Qt = ...
        WA_NoX11EventCompression: Qt = ...
        WA_TintedBackground: Qt = ...
        WA_X11OpenGLOverlay: Qt = ...
        WA_AttributeCount: Qt = ...
        WA_AlwaysShowToolTips: Qt = ...
        WA_MacOpaqueSizeGrip: Qt = ...
        WA_SetStyle: Qt = ...
        WA_SetLocale: Qt = ...
        WA_MacShowFocusRect: Qt = ...
        WA_MacNormalSize: Qt = ...
        WA_MacSmallSize: Qt = ...
        WA_MacMiniSize: Qt = ...
        WA_LayoutUsesWidgetRect: Qt = ...
        WA_StyledBackground: Qt = ...
        WA_MacAlwaysShowToolWindow: Qt = ...
        WA_StyleSheet: Qt = ...
        WA_ShowWithoutActivating: Qt = ...
        WA_NativeWindow: Qt = ...
        WA_DontCreateNativeAncestors: Qt = ...
        WA_DontShowOnScreen: Qt = ...
        WA_X11NetWmWindowTypeDesktop: Qt = ...
        WA_X11NetWmWindowTypeDock: Qt = ...
        WA_X11NetWmWindowTypeToolBar: Qt = ...
        WA_X11NetWmWindowTypeMenu: Qt = ...
        WA_X11NetWmWindowTypeUtility: Qt = ...
        WA_X11NetWmWindowTypeSplash: Qt = ...
        WA_X11NetWmWindowTypeDialog: Qt = ...
        WA_X11NetWmWindowTypeDropDownMenu: Qt = ...
        WA_X11NetWmWindowTypePopupMenu: Qt = ...
        WA_X11NetWmWindowTypeToolTip: Qt = ...
        WA_X11NetWmWindowTypeNotification: Qt = ...
        WA_X11NetWmWindowTypeCombo: Qt = ...
        WA_X11NetWmWindowTypeDND: Qt = ...
        WA_TranslucentBackground: Qt = ...
        WA_AcceptTouchEvents: Qt = ...
        WA_TouchPadAcceptSingleTouchEvents: Qt = ...
        WA_X11DoNotAcceptFocus: Qt = ...
        WA_AlwaysStackOnTop: Qt = ...
        WA_TabletTracking: Qt = ...
        WA_ContentsMarginsRespectsSafeArea: Qt = ...
        WA_StyleSheetTarget: Qt = ...

    class WindowState(enum.Flag):
        WindowNoState: Qt = ...
        WindowMinimized: Qt = ...
        WindowMaximized: Qt = ...
        WindowFullScreen: Qt = ...
        WindowActive: Qt = ...

    class WindowType(enum.IntFlag):
        Widget: Qt = ...
        Window: Qt = ...
        Dialog: Qt = ...
        Sheet: Qt = ...
        Drawer: Qt = ...
        Popup: Qt = ...
        Tool: Qt = ...
        ToolTip: Qt = ...
        SplashScreen: Qt = ...
        Desktop: Qt = ...
        SubWindow: Qt = ...
        WindowType_Mask: Qt = ...
        MSWindowsFixedSizeDialogHint: Qt = ...
        MSWindowsOwnDC: Qt = ...
        X11BypassWindowManagerHint: Qt = ...
        FramelessWindowHint: Qt = ...
        CustomizeWindowHint: Qt = ...
        WindowTitleHint: Qt = ...
        WindowSystemMenuHint: Qt = ...
        WindowMinimizeButtonHint: Qt = ...
        WindowMaximizeButtonHint: Qt = ...
        WindowMinMaxButtonsHint: Qt = ...
        WindowContextHelpButtonHint: Qt = ...
        WindowShadeButtonHint: Qt = ...
        WindowStaysOnTopHint: Qt = ...
        WindowStaysOnBottomHint: Qt = ...
        WindowCloseButtonHint: Qt = ...
        MacWindowToolBarButtonHint: Qt = ...
        BypassGraphicsProxyWidget: Qt = ...
        WindowTransparentForInput: Qt = ...
        WindowOverridesSystemGestures: Qt = ...
        WindowDoesNotAcceptFocus: Qt = ...
        NoDropShadowWindowHint: Qt = ...
        WindowFullscreenButtonHint: Qt = ...
        ForeignWindow: Qt = ...
        BypassWindowManagerHint: Qt = ...
        CoverWindow: Qt = ...
        MaximizeUsingFullscreenGeometryHint: Qt = ...

    class TextElideMode(enum.Enum):
        ElideLeft: Qt = ...
        ElideRight: Qt = ...
        ElideMiddle: Qt = ...
        ElideNone: Qt = ...

    class TextFlag(enum.IntFlag):
        TextSingleLine: Qt = ...
        TextDontClip: Qt = ...
        TextExpandTabs: Qt = ...
        TextShowMnemonic: Qt = ...
        TextWordWrap: Qt = ...
        TextWrapAnywhere: Qt = ...
        TextDontPrint: Qt = ...
        TextIncludeTrailingSpaces: Qt = ...
        TextHideMnemonic: Qt = ...
        TextJustificationForced: Qt = ...

    class AlignmentFlag(enum.IntFlag):
        AlignLeft: Qt = ...
        AlignLeading: Qt = ...
        AlignRight: Qt = ...
        AlignTrailing: Qt = ...
        AlignHCenter: Qt = ...
        AlignJustify: Qt = ...
        AlignAbsolute: Qt = ...
        AlignHorizontal_Mask: Qt = ...
        AlignTop: Qt = ...
        AlignBottom: Qt = ...
        AlignVCenter: Qt = ...
        AlignVertical_Mask: Qt = ...
        AlignCenter: Qt = ...
        AlignBaseline: Qt = ...

    class SortOrder(enum.Enum):
        AscendingOrder: Qt = ...
        DescendingOrder: Qt = ...

    class FocusPolicy(enum.Flag):
        NoFocus: Qt = ...
        TabFocus: Qt = ...
        ClickFocus: Qt = ...
        StrongFocus: Qt = ...
        WheelFocus: Qt = ...

    class Orientation(enum.Flag):
        Horizontal: Qt = ...
        Vertical: Qt = ...

    class MouseButton(enum.Flag):
        NoButton: Qt = ...
        AllButtons: Qt = ...
        LeftButton: Qt = ...
        RightButton: Qt = ...
        MiddleButton: Qt = ...
        XButton1: Qt = ...
        XButton2: Qt = ...
        BackButton: Qt = ...
        ExtraButton1: Qt = ...
        ForwardButton: Qt = ...
        ExtraButton2: Qt = ...
        TaskButton: Qt = ...
        ExtraButton3: Qt = ...
        ExtraButton4: Qt = ...
        ExtraButton5: Qt = ...
        ExtraButton6: Qt = ...
        ExtraButton7: Qt = ...
        ExtraButton8: Qt = ...
        ExtraButton9: Qt = ...
        ExtraButton10: Qt = ...
        ExtraButton11: Qt = ...
        ExtraButton12: Qt = ...
        ExtraButton13: Qt = ...
        ExtraButton14: Qt = ...
        ExtraButton15: Qt = ...
        ExtraButton16: Qt = ...
        ExtraButton17: Qt = ...
        ExtraButton18: Qt = ...
        ExtraButton19: Qt = ...
        ExtraButton20: Qt = ...
        ExtraButton21: Qt = ...
        ExtraButton22: Qt = ...
        ExtraButton23: Qt = ...
        ExtraButton24: Qt = ...

    class Modifier(enum.Flag):
        META: Qt = ...
        SHIFT: Qt = ...
        CTRL: Qt = ...
        ALT: Qt = ...
        MODIFIER_MASK: Qt = ...

    class KeyboardModifier(enum.Flag):
        NoModifier: Qt = ...
        ShiftModifier: Qt = ...
        ControlModifier: Qt = ...
        AltModifier: Qt = ...
        MetaModifier: Qt = ...
        KeypadModifier: Qt = ...
        GroupSwitchModifier: Qt = ...
        KeyboardModifierMask: Qt = ...

    class GlobalColor(enum.Enum):
        color0: Qt = ...
        color1: Qt = ...
        black: Qt = ...
        white: Qt = ...
        darkGray: Qt = ...
        gray: Qt = ...
        lightGray: Qt = ...
        red: Qt = ...
        green: Qt = ...
        blue: Qt = ...
        cyan: Qt = ...
        magenta: Qt = ...
        yellow: Qt = ...
        darkRed: Qt = ...
        darkGreen: Qt = ...
        darkBlue: Qt = ...
        darkCyan: Qt = ...
        darkMagenta: Qt = ...
        darkYellow: Qt = ...
        transparent: Qt = ...

    def ws(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#ws

        **[since 5.14] QTextStream &Qt::ws(QTextStream & stream )**

        Calls **skipWhiteSpace** () on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **QTextStream manipulators** .
        """
        ...

    def bom(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#bom

        **[since 5.14] QTextStream &Qt::bom(QTextStream & stream )**

        Toggles insertion of the Byte Order Mark on **stream** when
        **QTextStream**  is used with a UTF encoding.

        This function was introduced in Qt 5.14.

        **See also** **QTextStream::setGenerateByteOrderMark** () and
        **QTextStream manipulators** .
        """
        ...

    def reset(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#reset

        **[since 5.14] QTextStream &Qt::reset(QTextStream & stream )**

        Calls **QTextStream::reset** () on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **flush** () and **QTextStream manipulators** .
        """
        ...

    def flush(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#flush

        **[since 5.14] QTextStream &Qt::flush(QTextStream & stream )**

        Calls **QTextStream::flush** () on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **endl** (), **reset** (), and **QTextStream manipulators**
        .
        """
        ...

    def endl(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#endl

        **[since 5.14] QTextStream &Qt::endl(QTextStream & stream )**

        Writes '\\n' to the **stream** and flushes the stream.

        Equivalent to

        stream << '\\n' << Qt::flush;

        Note: On Windows, all '\\n' characters are written as '\\r\\n' if
        **QTextStream** 's device or string is opened using the QIODevice::Text
        flag.

        This function was introduced in Qt 5.14.

        **See also** **flush** (), **reset** (), and **QTextStream
        manipulators** .
        """
        ...

    def center(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#center

        **[since 5.14] QTextStream &Qt::center(QTextStream & stream )**

        Calls **QTextStream::setFieldAlignment** (**QTextStream::AlignCenter** )
        on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **left** (), **right** (), and **QTextStream manipulators**
        .
        """
        ...

    def right(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#right

        **[since 5.14] QTextStream &Qt::right(QTextStream & stream )**

        Calls **QTextStream::setFieldAlignment** (**QTextStream::AlignRight** )
        on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **left** (), **center** (), and **QTextStream
        manipulators** .
        """
        ...

    def left(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#left

        **[since 5.14] QTextStream &Qt::left(QTextStream & stream )**

        Calls **QTextStream::setFieldAlignment** (**QTextStream::AlignLeft** )
        on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **right** (), **center** (), and **QTextStream
        manipulators** .
        """
        ...

    def scientific(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#scientific

        **[since 5.14] QTextStream &Qt::scientific(QTextStream & stream )**

        Calls **QTextStream::setRealNumberNotation**
        (**QTextStream::ScientificNotation** ) on **stream** and returns
        **stream**.

        This function was introduced in Qt 5.14.

        **See also** **fixed** () and **QTextStream manipulators** .
        """
        ...

    def fixed(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#fixed

        **[since 5.14] QTextStream &Qt::fixed(QTextStream & stream )**

        Calls **QTextStream::setRealNumberNotation**
        (**QTextStream::FixedNotation** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **scientific** () and **QTextStream manipulators** .
        """
        ...

    def lowercasedigits(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#lowercasedigits

        **[since 5.14] QTextStream &Qt::lowercasedigits(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () &
        ~**QTextStream::UppercaseDigits** ) on **stream** and returns
        **stream**.

        This function was introduced in Qt 5.14.

        **See also** **uppercasedigits** (), **lowercasebase** (), and
        **QTextStream manipulators** .
        """
        ...

    def lowercasebase(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#lowercasebase

        **[since 5.14] QTextStream &Qt::lowercasebase(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () &
        ~**QTextStream::UppercaseBase** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **uppercasebase** (), **lowercasedigits** (), and
        **QTextStream manipulators** .
        """
        ...

    def uppercasedigits(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#uppercasedigits

        **[since 5.14] QTextStream &Qt::uppercasedigits(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () |
        **QTextStream::UppercaseDigits** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **lowercasedigits** (), **uppercasebase** (), and
        **QTextStream manipulators** .
        """
        ...

    def uppercasebase(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#uppercasebase

        **[since 5.14] QTextStream &Qt::uppercasebase(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () |
        **QTextStream::UppercaseBase** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **lowercasebase** (), **uppercasedigits** (), and
        **QTextStream manipulators** .
        """
        ...

    def noforcepoint(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#noforcepoint

        **[since 5.14] QTextStream &Qt::noforcepoint(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () &
        ~**QTextStream::ForcePoint** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **forcepoint** (), **noforcesign** (), **noshowbase** (),
        and **QTextStream manipulators** .
        """
        ...

    def noforcesign(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#noforcesign

        **[since 5.14] QTextStream &Qt::noforcesign(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () &
        ~**QTextStream::ForceSign** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **forcesign** (), **noforcepoint** (), **noshowbase** (),
        and **QTextStream manipulators** .
        """
        ...

    def noshowbase(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#noshowbase

        **[since 5.14] QTextStream &Qt::noshowbase(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () &
        ~**QTextStream::ShowBase** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **showbase** (), **noforcesign** (), **noforcepoint** (),
        and **QTextStream manipulators** .
        """
        ...

    def forcepoint(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#forcepoint

        **[since 5.14] QTextStream &Qt::forcepoint(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () |
        **QTextStream::ForcePoint** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **noforcepoint** (), **forcesign** (), **showbase** (), and
        **QTextStream manipulators** .
        """
        ...

    def forcesign(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#forcesign

        **[since 5.14] QTextStream &Qt::forcesign(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () |
        **QTextStream::ForceSign** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **noforcesign** (), **forcepoint** (), **showbase** (), and
        **QTextStream manipulators** .
        """
        ...

    def showbase(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#showbase

        **[since 5.14] QTextStream &Qt::showbase(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () |
        **QTextStream::ShowBase** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **noshowbase** (), **forcesign** (), **forcepoint** (), and
        **QTextStream manipulators** .
        """
        ...

    def hex(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#hex

        **[since 5.14] QTextStream &Qt::hex(QTextStream & stream )**

        Calls **QTextStream::setIntegerBase** (16) on **stream** and returns
        **stream**.

        **Note:** The hex modifier can only be used for writing to streams.

        This function was introduced in Qt 5.14.

        **See also** **bin** (), **oct** (), **dec** (), and **QTextStream
        manipulators** .
        """
        ...

    def dec(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#dec

        **[since 5.14] QTextStream &Qt::dec(QTextStream & stream )**

        Calls **QTextStream::setIntegerBase** (10) on **stream** and returns
        **stream**.

        This function was introduced in Qt 5.14.

        **See also** **bin** (), **oct** (), **hex** (), and **QTextStream
        manipulators** .
        """
        ...

    def oct(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#oct

        **[since 5.14] QTextStream &Qt::oct(QTextStream & stream )**

        Calls **QTextStream::setIntegerBase** (8) on **stream** and returns
        **stream**.

        This function was introduced in Qt 5.14.

        **See also** **bin** (), **dec** (), **hex** (), and **QTextStream
        manipulators** .
        """
        ...

    def bin(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#bin

        **[since 5.14] QTextStream &Qt::bin(QTextStream & stream )**

        Calls **QTextStream::setIntegerBase** (2) on **stream** and returns
        **stream**.

        This function was introduced in Qt 5.14.

        **See also** **oct** (), **dec** (), **hex** (), and **QTextStream
        manipulators** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QGeoAddress(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qgeoaddress.html

    **Detailed Description**

    The address' attributes are normalized to US feature names and can be mapped
    to the local feature levels (for example State matches "Bundesland" in
    Germany).

    The address contains a **text** () for displaying purposes and additional
    properties to access the components of an address:

    * **QGeoAddress::country** ()
      * **QGeoAddress::countryCode** ()
      *
    **QGeoAddress::state** ()
      * **QGeoAddress::city** ()
      *
    **QGeoAddress::district** ()
      * **QGeoAddress::street** ()
      *
    **QGeoAddress::postalCode** ()
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#QGeoAddress

        **QGeoAddress::QGeoAddress()**

        Default constructor.
        """
        ...

    @typing.overload
    def __init__(self, other: "QGeoAddress") -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#QGeoAddress-1

        **QGeoAddress::QGeoAddress(const QGeoAddress & other )**

        Constructs a copy of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def setStreetNumber(self, streetNumber: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#setStreetNumber

        **[since 6.2] void QGeoAddress::setStreetNumber(const QString &
        streetNumber )**

        Sets the street number to **streetNumber**.

        This may also contain things like a unit number, a building name, or
        anything else that might be used to distinguish one address from
        another.

        **Note:** Before Qt6 this information was set by **setStreet** ()
        method.

        This function was introduced in Qt 6.2.

        **See also** **streetNumber** () and **setStreet** ().
        """
        ...

    def streetNumber(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#streetNumber

        **[since 6.2] QString QGeoAddress::streetNumber() const**

        Returns the street number.

        This may also contain things like a unit number, a building name, or
        anything else that might be used to distinguish one address from
        another.

        **Note:** Before Qt6 this information was returned by **street** ()
        method.

        This function was introduced in Qt 6.2.

        **See also** **setStreetNumber** () and **street** ().
        """
        ...

    def swap(self, other: "QGeoAddress") -> None:
        ...

    def isTextGenerated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#isTextGenerated

        **bool QGeoAddress::isTextGenerated() const**

        Returns true if **QGeoAddress::text** () is automatically generated from
        address elements, otherwise returns false if **text** () has been
        explicitly assigned.

        **See also** **text** () and **setText** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#clear

        **void QGeoAddress::clear()**

        Clears all of the address' data fields.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#isEmpty

        **bool QGeoAddress::isEmpty() const**

        Returns whether this address is empty. An address is considered empty if
        **all** of its fields are empty.
        """
        ...

    def setStreet(self, street: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#setStreet

        **void QGeoAddress::setStreet(const QString & street )**

        Sets the street name to **street**.

        **Note:** Before Qt6 this could also contain things like a unit number,
        a building name, or anything else that might be used to distinguish one
        address from another. Use **setStreetNumber** () to set this data now.

        **See also** **street** () and **setStreetNumber** ().
        """
        ...

    def street(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#street

        **QString QGeoAddress::street() const**

        Returns the street name.

        **Note:** Before Qt6 this could also contain things like a unit number,
        a building name, or anything else that might be used to distinguish one
        address from another. Use **streetNumber** () to obtain this data now.

        **See also** **setStreet** () and **streetNumber** ().
        """
        ...

    def setPostalCode(self, postalCode: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#setPostalCode

        **void QGeoAddress::setPostalCode(const QString & postalCode )**

        Sets the **postalCode**.

        **See also** **postalCode** ().
        """
        ...

    def postalCode(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#postalCode

        **QString QGeoAddress::postalCode() const**

        Returns the postal code.

        **See also** **setPostalCode** ().
        """
        ...

    def setDistrict(self, district: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#setDistrict

        **void QGeoAddress::setDistrict(const QString & district )**

        Sets the **district**.

        **See also** **district** ().
        """
        ...

    def district(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#district

        **QString QGeoAddress::district() const**

        Returns the district. The district is considered the subdivison below
        city.

        **See also** **setDistrict** ().
        """
        ...

    def setCity(self, city: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#setCity

        **void QGeoAddress::setCity(const QString & city )**

        Sets the **city**.

        **See also** **city** ().
        """
        ...

    def city(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#city

        **QString QGeoAddress::city() const**

        Returns the city.

        **See also** **setCity** ().
        """
        ...

    def setCounty(self, county: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#setCounty

        **void QGeoAddress::setCounty(const QString & county )**

        Sets the **county**.

        **See also** **county** ().
        """
        ...

    def county(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#county

        **QString QGeoAddress::county() const**

        Returns the county. The county is considered the second subdivision
        below country.

        **See also** **setCounty** ().
        """
        ...

    def setState(self, state: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#setState

        **void QGeoAddress::setState(const QString & state )**

        Sets the **state**.

        **See also** **state** ().
        """
        ...

    def state(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#state

        **QString QGeoAddress::state() const**

        Returns the state. The state is considered the first subdivision below
        country.

        **See also** **setState** ().
        """
        ...

    def setCountryCode(self, countryCode: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#setCountryCode

        **void QGeoAddress::setCountryCode(const QString & countryCode )**

        Sets the **countryCode** according to ISO 3166-1 alpha-3

        **See also** **countryCode** ().
        """
        ...

    def countryCode(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#countryCode

        **QString QGeoAddress::countryCode() const**

        Returns the country code according to ISO 3166-1 alpha-3

        **See also** **setCountryCode** ().
        """
        ...

    def setCountry(self, country: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#setCountry

        **void QGeoAddress::setCountry(const QString & country )**

        Sets the **country** name.

        **See also** **country** ().
        """
        ...

    def country(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#country

        **QString QGeoAddress::country() const**

        Returns the country name.

        **See also** **setCountry** ().
        """
        ...

    def setText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#setText

        **void QGeoAddress::setText(const QString & text )**

        If **text** is not empty, explicitly assigns **text** as the string to
        be returned by **text** (). **isTextGenerated** () will return false.

        If **text** is empty, indicates that **text** () should be automatically
        generated from the address elements. **isTextGenerated** () will return
        true.

        **See also** **text** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoaddress.html#text

        **QString QGeoAddress::text() const**

        Returns the address as a single formatted string. It is the recommended
        string to use to display the address to the user. It typically takes the
        format of an address as found on an envelope, but this is not always
        necessarily the case.

        The address text is either automatically generated or explicitly
        assigned. This can be determined by checking **isTextGenerated** .

        If an empty string is provided to **setText** (), then
        **isTextGenerated** () will be set to `true` and text() will return a
        string which is locally formatted according to **countryCode** () and
        based on the elements of the address such as street, city and so on.
        Because the text string is generated from the address elements, a
        sequence of calls such as text(), **setStreet** (), text() may return
        different strings for each invocation of text().

        If a non-empty string is provided to **setText** (), then
        **isTextGenerated** () will be set to `false` and text() will always
        return the explicitly assigned string. Calls to modify other elements
        such as **setStreet** (), **setCity** () and so on will not affect the
        resultant string from text().

        **See also** **setText** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QSemaphore(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsemaphore.html

    **Detailed Description**

    A semaphore is a generalization of a mutex. While a mutex can only be locked
    once, it's possible to acquire a semaphore multiple times. Semaphores are
    typically used to protect a certain number of identical resources.

    Semaphores support two fundamental operations, **acquire** () and
    **release** ():

    * acquire( **n** ) tries to acquire **n** resources. If there aren't that
    many resources available, the call will block until this is the case.
      *
    release( **n** ) releases **n** resources.

    There's also a **tryAcquire** () function that returns immediately if it
    cannot acquire the resources, and an **available** () function that returns
    the number of available resources at any time.

    Example:

    **QSemaphore**  sem(5);      // sem.available() == 5
    sem.acquire(3);         // sem.available() == 2
        sem.acquire(2);
    // sem.available() == 0
        sem.release(5);         // sem.available() == 5
    sem.release(5);         // sem.available() == 10

        sem.tryAcquire(1);
    // sem.available() == 9, returns true
        sem.tryAcquire(250);    //
    sem.available() == 9, returns false

    A typical application of semaphores is for controlling access to a circular
    buffer shared by a producer thread and a consumer thread. The **Semaphores
    Example**  shows how to use QSemaphore to solve that problem.

    A non-computing example of a semaphore would be dining at a restaurant. A
    semaphore is initialized with the number of chairs in the restaurant. As
    people arrive, they want a seat. As seats are filled, **available** () is
    decremented. As people leave, the **available** () is incremented, allowing
    more people to enter. If a party of 10 people want to be seated, but there
    are only 9 seats, those 10 people will wait, but a party of 4 people would
    be seated (taking the available seats to 5, making the party of 10 people
    wait longer).

    **See also** **QSemaphoreReleaser** , **QMutex** , **QWaitCondition** ,
    **QThread** , and **Semaphores Example** .
    """

    def __init__(self, n: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsemaphore.html#QSemaphore

        **QSemaphore::QSemaphore(int n = 0)**

        Creates a new semaphore and initializes the number of resources it
        guards to **n** (by default, 0).

        **See also** **release** () and **available** ().
        """
        ...

    def available(self) -> int:
        """
        https://doc.qt.io/qt-6/qsemaphore.html#available

        **int QSemaphore::available() const**

        Returns the number of resources currently available to the semaphore.
        This number can never be negative.

        **See also** **acquire** () and **release** ().
        """
        ...

    def release(self, n: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsemaphore.html#release

        **void QSemaphore::release(int n = 1)**

        Releases **n** resources guarded by the semaphore.

        This function can be used to "create" resources as well. For example:

        **QSemaphore**  sem(5);      // a semaphore that guards 5 resources
        sem.acquire(5);         // acquire all 5 resources
            sem.release(5);
        // release the 5 resources
            sem.release(10);        // "create" 10
        new resources

        **QSemaphoreReleaser**  is a **RAII**  wrapper around this function.

        **See also** **acquire** (), **available** (), and
        **QSemaphoreReleaser** .
        """
        ...

    @typing.overload
    def tryAcquire(self, n: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsemaphore.html#tryAcquire

        **bool QSemaphore::tryAcquire(int n = 1)**

        Tries to acquire `n` resources guarded by the semaphore and returns
        `true` on success. If **available** () < **n** , this call immediately
        returns `false` without acquiring any resources.

        Example:

        **QSemaphore**  sem(5);      // sem.available() == 5
        sem.tryAcquire(250);    // sem.available() == 5, returns false
        sem.tryAcquire(3);      // sem.available() == 2, returns true

        **See also** **acquire** ().
        """
        ...

    @typing.overload
    def tryAcquire(self, n: int, timeout: int) -> bool:
        """
        https://doc.qt.io/qt-6/qsemaphore.html#tryAcquire-1

        **bool QSemaphore::tryAcquire(int n , int timeout )**

        Tries to acquire `n` resources guarded by the semaphore and returns
        `true` on success. If **available** () < **n** , this call will wait for
        at most **timeout** milliseconds for resources to become available.

        Note: Passing a negative number as the **timeout** is equivalent to
        calling **acquire** (), i.e. this function will wait forever for
        resources to become available if **timeout** is negative.

        Example:

        **QSemaphore**  sem(5);            // sem.available() == 5
        sem.tryAcquire(250, 1000);    // sem.available() == 5, waits 1000
        milliseconds and returns false
            sem.tryAcquire(3, 30000);     //
        sem.available() == 2, returns true without waiting

        **See also** **acquire** ().
        """
        ...

    def acquire(self, n: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsemaphore.html#acquire

        **void QSemaphore::acquire(int n = 1)**

        Tries to acquire `n` resources guarded by the semaphore. If **n** >
        **available** (), this call will block until enough resources are
        available.

        **See also** **release** (), **available** (), and **tryAcquire** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QBluetooth import QBluetooth as QBluetooth
from ._QBluetoothAddress import QBluetoothAddress as QBluetoothAddress
from ._QBluetoothDeviceDiscoveryAgent import (
    QBluetoothDeviceDiscoveryAgent as QBluetoothDeviceDiscoveryAgent,
)
from ._QBluetoothDeviceInfo import QBluetoothDeviceInfo as QBluetoothDeviceInfo
from ._QBluetoothHostInfo import QBluetoothHostInfo as QBluetoothHostInfo
from ._QBluetoothLocalDevice import QBluetoothLocalDevice as QBluetoothLocalDevice
from ._QBluetoothServer import QBluetoothServer as QBluetoothServer
from ._QBluetoothServiceDiscoveryAgent import (
    QBluetoothServiceDiscoveryAgent as QBluetoothServiceDiscoveryAgent,
)
from ._QBluetoothServiceInfo import QBluetoothServiceInfo as QBluetoothServiceInfo
from ._QBluetoothSocket import QBluetoothSocket as QBluetoothSocket
from ._QBluetoothUuid import QBluetoothUuid as QBluetoothUuid
from ._QLowEnergyAdvertisingData import (
    QLowEnergyAdvertisingData as QLowEnergyAdvertisingData,
)
from ._QLowEnergyAdvertisingParameters import (
    QLowEnergyAdvertisingParameters as QLowEnergyAdvertisingParameters,
)
from ._QLowEnergyCharacteristic import (
    QLowEnergyCharacteristic as QLowEnergyCharacteristic,
)
from ._QLowEnergyCharacteristicData import (
    QLowEnergyCharacteristicData as QLowEnergyCharacteristicData,
)
from ._QLowEnergyConnectionParameters import (
    QLowEnergyConnectionParameters as QLowEnergyConnectionParameters,
)
from ._QLowEnergyController import QLowEnergyController as QLowEnergyController
from ._QLowEnergyDescriptor import QLowEnergyDescriptor as QLowEnergyDescriptor
from ._QLowEnergyDescriptorData import (
    QLowEnergyDescriptorData as QLowEnergyDescriptorData,
)
from ._QLowEnergyService import QLowEnergyService as QLowEnergyService
from ._QLowEnergyServiceData import QLowEnergyServiceData as QLowEnergyServiceData



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QErrorMessage(QDialog):
    """
    https://doc.qt.io/qt-6/qerrormessage.html

    **Detailed Description**

    An error message widget consists of a text label and a checkbox. The
    checkbox lets the user control whether the same error message will be
    displayed again in the future, typically displaying the text, "Show this
    message again" translated into the appropriate local language.

    For production applications, the class can be used to display messages which
    the user only needs to see once. To use QErrorMessage like this, you create
    the dialog in the usual way, and show it by calling the **showMessage** ()
    slot or connecting signals to it.

    The static **qtHandler** () function installs a message handler using
    **qInstallMessageHandler** () and creates a QErrorMessage that displays
    **qDebug** (), **qWarning** () and **qFatal** () messages. This is most
    useful in environments where no console is available to display warnings and
    error messages.

    In both cases QErrorMessage will queue pending messages and display them in
    order, with each new message being shown as soon as the user has accepted
    the previous message. Once the user has specified that a message is not to
    be shown again it is automatically skipped, and the dialog will show the
    next appropriate message in the queue.

    The **Standard Dialogs**  example shows how to use QErrorMessage as well as
    other built-in Qt dialogs.

    ![](images/qerrormessage.png)

    **See also** **QMessageBox** , **QStatusBar::showMessage** (), and
    **Standard Dialogs Example** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qerrormessage.html#QErrorMessage

        **QErrorMessage::QErrorMessage(QWidget * parent = nullptr)**

        Constructs and installs an error handler window with the given
        **parent**.
        """
        ...

    def done(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qerrormessage.html#done

        **[override virtual protected] void QErrorMessage::done(int a )**

        Reimplements: **QDialog::done** (int r).
        """
        ...

    def changeEvent(self, e: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qerrormessage.html#changeEvent

        **[override virtual protected] void QErrorMessage::changeEvent(QEvent *
        e )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    @typing.overload
    def showMessage(self, message: str) -> None:
        """
        https://doc.qt.io/qt-6/qerrormessage.html#showMessage

        **[slot] void QErrorMessage::showMessage(const QString & message )**

        Shows the given message, **message** , and returns immediately. If the
        user has requested for the message not to be shown again, this function
        does nothing.

        Normally, the message is displayed immediately. However, if there are
        pending messages, it will be queued to be displayed later.
        """
        ...

    @typing.overload
    def showMessage(self, message: str, type: str) -> None:
        """
        https://doc.qt.io/qt-6/qerrormessage.html#showMessage-1

        **[slot] void QErrorMessage::showMessage(const QString & message , const
        QString & type )**

        This is an overloaded function.

        Shows the given message, **message** , and returns immediately. If the
        user has requested for messages of type, **type** , not to be shown
        again, this function does nothing.

        Normally, the message is displayed immediately. However, if there are
        pending messages, it will be queued to be displayed later.

        **See also** **showMessage** ().
        """
        ...

    @staticmethod
    def qtHandler() -> "QErrorMessage":
        """
        https://doc.qt.io/qt-6/qerrormessage.html#qtHandler

        **[static] QErrorMessage *QErrorMessage::qtHandler()**

        Returns a pointer to a **QErrorMessage**  object that outputs the
        default Qt messages. This function creates such an object, if there
        isn't one already.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsSceneMoveEvent(QGraphicsSceneEvent):
    """
    https://doc.qt.io/qt-6/qgraphicsscenemoveevent.html

    **Detailed Description**

    A **QGraphicsWidget**  sends itself a QGraphicsSceneMoveEvent immediately
    when its local position changes. The delivery is implemented as part of
    **QGraphicsItem::itemChange** ().

    It's similar to **QMoveEvent** , but its positions, **oldPos** () and
    **newPos** (), use **QPointF**  instead of **QPoint** .

    **See also** **QGraphicsItem::setPos** (),
    **QGraphicsItem::ItemPositionChange** , and
    **QGraphicsItem::ItemPositionHasChanged** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemoveevent.html#QGraphicsSceneMoveEv
        ent-1

        **QGraphicsSceneMoveEvent::QGraphicsSceneMoveEvent()**

        Constructs a QGraphicsSceneMoveEvent.
        """
        ...

    def newPos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemoveevent.html#newPos

        **QPointF QGraphicsSceneMoveEvent::newPos() const**

        Returns the new position (i.e., the current position).

        **See also** **oldPos** () and **QGraphicsItem::setPos** ().
        """
        ...

    def oldPos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemoveevent.html#oldPos

        **QPointF QGraphicsSceneMoveEvent::oldPos() const**

        Returns the old position (i.e., the position immediately before the
        widget was moved).

        **See also** **newPos** () and **QGraphicsItem::setPos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QConicalGradient(QGradient):
    """
    https://doc.qt.io/qt-6/qconicalgradient.html

    **Detailed Description**

    Conical gradients interpolate interpolate colors counter-clockwise around a
    center point.

    ![](images/qconicalgradient.png)

    The colors in a gradient is defined using stop points of the
    **QGradientStop**  type, i.e. a position and a color. Use the
    **QGradient::setColorAt** () or the **QGradient::setStops** () function to
    define the stop points. It is the gradient's complete set of stop points
    that describes how the gradient area should be filled. If no stop points
    have been specified, a gradient of black at 0 to white at 1 is used.

    In addition to the functions inherited from **QGradient** , the
    QConicalGradient class provides the **angle** () and **center** () functions
    returning the start angle and center of the gradient.

    Note that the **setSpread** () function has no effect for conical gradients.
    The reason is that the conical gradient is closed by definition, i.e. the
    conical gradient fills the entire circle from 0 - 360 degrees, while the
    boundary of a radial or a linear gradient can be specified through its
    radius or final stop points, respectively.

    **See also** **QLinearGradient** , **QRadialGradient** , and **The Gradients
    Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qconicalgradient.html#QConicalGradient

        **QConicalGradient::QConicalGradient()**

        Constructs a conical with center at (0, 0) starting the interpolation at
        angle 0.

        **See also** **QGradient::setColorAt** (), **setCenter** (), and
        **setAngle** ().
        """
        ...

    @typing.overload
    def __init__(self, center: QtCore.QPointF, startAngle: float) -> None:
        """
        https://doc.qt.io/qt-6/qconicalgradient.html#QConicalGradient-1

        **QConicalGradient::QConicalGradient(const QPointF & center , qreal
        angle )**

        Constructs a conical gradient with the given **center** , starting the
        interpolation at the given **angle**. The **angle** must be specified in
        degrees between 0 and 360.

        **See also** **QGradient::setColorAt** () and **QGradient::setStops**
        ().
        """
        ...

    @typing.overload
    def __init__(self, cx: float, cy: float, startAngle: float) -> None:
        """
        https://doc.qt.io/qt-6/qconicalgradient.html#QConicalGradient-2

        **QConicalGradient::QConicalGradient(qreal cx , qreal cy , qreal angle
        )**

        Constructs a conical gradient with the given center ( **cx** , **cy** ),
        starting the interpolation at the given **angle**. The angle must be
        specified in degrees between 0 and 360.

        **See also** **QGradient::setColorAt** () and **QGradient::setStops**
        ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QConicalGradient") -> None:
        """
        https://doc.qt.io/qt-6/qconicalgradient.html#QConicalGradient

        **QConicalGradient::QConicalGradient()**

        Constructs a conical with center at (0, 0) starting the interpolation at
        angle 0.

        **See also** **QGradient::setColorAt** (), **setCenter** (), and
        **setAngle** ().
        """
        ...

    def setAngle(self, angle: float) -> None:
        """
        https://doc.qt.io/qt-6/qconicalgradient.html#setAngle

        **void QConicalGradient::setAngle(qreal angle )**

        Sets **angle** to be the start angle for this conical gradient in
        logical coordinates.

        **See also** **angle** ().
        """
        ...

    @typing.overload
    def setCenter(self, center: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qconicalgradient.html#setCenter

        **void QConicalGradient::setCenter(const QPointF & center )**

        Sets the center of this conical gradient in logical coordinates to
        **center**.

        **See also** **center** ().
        """
        ...

    @typing.overload
    def setCenter(self, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qconicalgradient.html#setCenter-1

        **void QConicalGradient::setCenter(qreal x , qreal y )**

        This is an overloaded function.

        Sets the center of this conical gradient in logical coordinates to (
        **x** , **y** ).

        **See also** **center** ().
        """
        ...

    def angle(self) -> float:
        """
        https://doc.qt.io/qt-6/qconicalgradient.html#angle

        **qreal QConicalGradient::angle() const**

        Returns the start angle of the conical gradient in logical coordinates.

        **See also** **setAngle** () and **stops** ().
        """
        ...

    def center(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qconicalgradient.html#center

        **QPointF QConicalGradient::center() const**

        Returns the center of the conical gradient in logical coordinates.

        **See also** **setCenter** () and **stops** ().
        """
        ...
